@@ -6,8 +6,8 @@ from django.contrib.contenttypes.fields import GenericForeignKey
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import PermissionDenied
 from django.db import models
-from django.db.models import CharField, Value, Q
-from django.db.models.functions import Concat
+from django.db.models import CharField, Q, Value
+from django.db.models.functions import Cast, Concat
 from django.utils.encoding import force_text
 from django.utils.translation import ugettext
 
@@ -29,14 +29,15 @@ class AccessControlListManager(models.Manager):
     and an object
     """
     def _get_acl_filters(
-        self, queryset, stored_permission, user, related_field_name=None
+        self, queryset, stored_permission, user, fk_field_cast=None,
+        related_field_name=None
     ):
         """
         This method does the bulk of the work. It generates filters for the
         AccessControlList model to determine if there are ACL entries for the
         members of the queryset's model provided.
         """
-        # Determine which of the cases we need to address
+        # Determine which of the cases we need to address:
         # 1: No related field
         # 2: Related field
         # 3: Related field that is Generic Foreign Key
@@ -55,7 +56,7 @@ class AccessControlListManager(models.Manager):
 
             if isinstance(related_field, GenericForeignKey):
                 # Case 3: Generic Foreign Key, multiple ContentTypes + object
-                # id combinations
+                # id combinations.
                 # Also handles case #6 using the parent related field
                 # reference template.
 
@@ -63,20 +64,20 @@ class AccessControlListManager(models.Manager):
                 # field in the case where multiple related fields are
                 # associated.
                 # Example: object_layer__content_type
-                recuisive_related_reference = '__'.join(related_field_name.split('__')[0:-1])
+                recursive_related_reference = '__'.join(related_field_name.split('__')[0:-1])
 
                 # If there is at least one parent related field we add a
                 # double underscore to make it a valid filter template.
-                if recuisive_related_reference:
-                    recuisive_related_reference = '{}__'.format(recuisive_related_reference)
+                if recursive_related_reference:
+                    recursive_related_reference = '{}__'.format(recursive_related_reference)
 
                 content_type_object_id_queryset = queryset.annotate(
                     ct_fk_combination=Concat(
                         '{}{}'.format(
-                            recuisive_related_reference, related_field.ct_field
+                            recursive_related_reference, related_field.ct_field
                         ), Value('-'),
                         '{}{}'.format(
-                            recuisive_related_reference, related_field.fk_field
+                            recursive_related_reference, related_field.fk_field
                         ), output_field=CharField()
                     )
                 ).values('ct_fk_combination')
@@ -89,13 +90,24 @@ class AccessControlListManager(models.Manager):
                 ).filter(
                     permissions=stored_permission, role__groups__user=user,
                     ct_fk_combination__in=content_type_object_id_queryset
-                ).values('object_id')
+                )
 
-                field_lookup = '{}object_id__in'.format(recuisive_related_reference)
-                result.append(Q(**{field_lookup: acl_filter}))
+                if fk_field_cast:
+                    clean_acl_filter = acl_filter.annotate(
+                        clean_object_id=Cast(
+                            'object_id', output_field=fk_field_cast()
+                        )
+                    ).values_list('clean_object_id')
+                else:
+                    clean_acl_filter = acl_filter.values('object_id')
+
+                field_lookup = '{}{}__in'.format(
+                    recursive_related_reference, related_field.fk_field
+                )
+                result.append(Q(**{field_lookup: clean_acl_filter}))
             else:
                 # Case 2: Related field of a single type, single ContentType,
-                # multiple object id
+                # multiple object id.
                 content_type = ContentType.objects.get_for_model(
                     model=related_field.related_model
                 )
@@ -111,27 +123,25 @@ class AccessControlListManager(models.Manager):
                     result.append(Q(**{field_lookup: acl_filter}))
 
                 # Case 5: Related field, has an inherited related field itself
-                # Bubble up permssion check
-                # Recurse and reduce
-                # TODO: Add relationship support: OR or AND
-                # TODO: OR for document pages, version, doc, and types
-                # TODO: AND for new cabinet levels ACLs
+                # Bubble up permission check.
+                # Recurse and reduce.
                 try:
-                    related_field_model_related_fields = (
-                        ModelPermission.get_inheritance(
+                    related_field_model_inheritances = (
+                        ModelPermission.get_inheritances(
                             model=related_field.related_model
-                        ),
+                        )
                     )
                 except KeyError:
                     pass
                 else:
                     relation_result = []
-                    for related_field_model_related_field_name in related_field_model_related_fields:
-                        related_field_name = '{}__{}'.format(related_field_name, related_field_model_related_field_name)
+                    for related_field_model_inheritance in related_field_model_inheritances:
+                        new_related_field_name = '{}__{}'.format(related_field_name, related_field_model_inheritance['field_name'])
                         related_field_inherited_acl_queries = self._get_acl_filters(
+                            fk_field_cast=related_field_model_inheritance['fk_field_cast'],
                             queryset=queryset,
                             stored_permission=stored_permission, user=user,
-                            related_field_name=related_field_name
+                            related_field_name=new_related_field_name
                         )
                         if related_field_inherited_acl_queries:
                             relation_result.append(
@@ -144,7 +154,7 @@ class AccessControlListManager(models.Manager):
                     if relation_result:
                         result.append(reduce(operator.or_, relation_result))
         else:
-            # Case 1: Original model, single ContentType, multiple object id
+            # Case 1: Original model, single ContentType, multiple object id.
             content_type = ContentType.objects.get_for_model(
                 model=queryset.model
             )
@@ -155,22 +165,25 @@ class AccessControlListManager(models.Manager):
             ).values('object_id')
             result.append(Q(**{field_lookup: acl_filter}))
 
-            # Case 4: Original model, has an inherited related field
+            # Case 4: Original model, has an inherited related field.
             try:
-                related_fields = (
-                    ModelPermission.get_inheritance(
+                inheritances = (
+                    ModelPermission.get_inheritances(
                         model=queryset.model
-                    ),
+                    )
                 )
             except KeyError:
-                pass
+                """
+                Does not have inheritance entries. Proceed to next case.
+                """
             else:
                 relation_result = []
 
-                for related_field_name in related_fields:
+                for inheritance in inheritances:
                     inherited_acl_queries = self._get_acl_filters(
+                        fk_field_cast=inheritance['fk_field_cast'],
                         queryset=queryset, stored_permission=stored_permission,
-                        related_field_name=related_field_name, user=user
+                        related_field_name=inheritance['field_name'], user=user
                     )
                     if inherited_acl_queries:
                         relation_result.append(
@@ -180,7 +193,7 @@ class AccessControlListManager(models.Manager):
                 if relation_result:
                     result.append(reduce(operator.or_, relation_result))
 
-            # Case 7: Has a function
+            # Case 7: Has a function.
             try:
                 field_query_function = ModelPermission.get_field_query_function(
                     model=queryset.model
@@ -190,7 +203,7 @@ class AccessControlListManager(models.Manager):
             else:
                 function_results = field_query_function()
 
-                # Filter by the model's content type
+                # Filter by the model's content type.
                 content_type = ContentType.objects.get_for_model(
                     model=queryset.model
                 )
@@ -198,7 +211,8 @@ class AccessControlListManager(models.Manager):
                     content_type=content_type, permissions=stored_permission,
                     role__groups__user=user
                 ).values('object_id')
-                # Obtain an queryset of filtered, authorized model instances
+
+                # Obtain a queryset of filtered, authorized model instances.
                 acl_queryset = queryset.model._meta.default_manager.filter(
                     id__in=acl_filter
                 ).filter(**function_results['acl_filter'])
@@ -209,7 +223,7 @@ class AccessControlListManager(models.Manager):
                     )
 
                 # Get the final query using the filtered queryset as the
-                # reference
+                # reference.
                 result.append(
                     Q(**{function_results['field_lookup']: acl_queryset})
                 )
@@ -228,7 +242,7 @@ class AccessControlListManager(models.Manager):
                 ugettext(
                     'Object "%s" is not a model and cannot be checked for '
                     'access.'
-                ) % force_text(obj)
+                ) % force_text(s=obj)
             )
             return True
         else:
@@ -237,8 +251,7 @@ class AccessControlListManager(models.Manager):
 
         restricted_queryset = manager.none()
         for permission in permissions:
-            # Default relationship betweens permissions is OR
-            # TODO: Add support for AND relationship
+            # Default relationship betweens permissions is OR.
             restricted_queryset = restricted_queryset | self.restrict_queryset(
                 permission=permission, queryset=source_queryset, user=user
             )
@@ -276,18 +289,18 @@ class AccessControlListManager(models.Manager):
 
             return queryset.filter(final_query)
         else:
-            # User has direct permission assignment via a role, is superuser or
-            # is staff. Return the entire queryset.
+            # User has direct permission assignment via a role, is superuser
+            # or is staff. Return the entire queryset.
             return queryset
 
     def get_inherited_permissions(self, obj, role):
-        # Get permission inherited from a related object's ACLs
+        # Get permission inherited from a related object's ACLs.
         queryset = self._get_inherited_object_permissions(obj=obj, role=role)
 
         # Get permission granted to the role
         queryset = queryset | role.permissions.all()
 
-        # Filter the permissions to the ones that apply to the model
+        # Filter the permissions to the ones that apply to the model.
         queryset = ModelPermission.get_for_instance(
             instance=obj
         ).filter(
@@ -303,40 +316,43 @@ class AccessControlListManager(models.Manager):
             return queryset
 
         try:
-            related_field = ModelPermission.get_inheritance(
+            inheritances = ModelPermission.get_inheritances(
                 model=type(obj)
             )
         except KeyError:
-            pass
+            """
+            Does not have inheritance to other models.
+            """
         else:
-            try:
-                parent_object = resolve_attribute(
-                    obj=obj, attribute=related_field
+            for inheritance in inheritances:
+                try:
+                    parent_object = resolve_attribute(
+                        obj=obj, attribute=inheritance['field_name']
+                    )
+                except AttributeError:
+                    # Parent accessor is not an attribute, try it as a related
+                    # field.
+                    parent_object = return_related(
+                        instance=obj, related_field=inheritance['field_name']
+                    )
+                content_type = ContentType.objects.get_for_model(
+                    model=parent_object
                 )
-            except AttributeError:
-                # Parent accessor is not an attribute, try it as a related
-                # field.
-                parent_object = return_related(
-                    instance=obj, related_field=related_field
-                )
-            content_type = ContentType.objects.get_for_model(
-                model=parent_object
-            )
-            try:
-                queryset = queryset | self.get(
-                    content_type=content_type, object_id=parent_object.pk,
-                    role=role
-                ).permissions.all()
-            except self.model.DoesNotExist:
-                pass
+                try:
+                    queryset = queryset | self.get(
+                        content_type=content_type, object_id=parent_object.pk,
+                        role=role
+                    ).permissions.all()
+                except self.model.DoesNotExist:
+                    pass
 
-            if type(parent_object) == type(obj):
-                # Object and parent are of the same type. Break recursion
-                return queryset
-            else:
-                queryset = queryset | self._get_inherited_object_permissions(
-                    obj=parent_object, role=role
-                )
+                if type(parent_object) == type(obj):
+                    # Object and parent are of the same type. Break recursion.
+                    return queryset
+                else:
+                    queryset = queryset | self._get_inherited_object_permissions(
+                        obj=parent_object, role=role
+                    )
 
         return queryset
 
