@@ -1,7 +1,7 @@
 import logging
 
-from mayan.apps.common.tests.base import BaseTestCase
-from mayan.apps.common.tests.utils import mute_stdout
+from mayan.apps.testing.tests.base import BaseTestCase
+from mayan.apps.testing.tests.utils import mute_stdout
 
 from ..models import AutoAdminSingleton
 from ..settings import setting_username
@@ -24,7 +24,7 @@ class AutoAdminHandlerTestCase(BaseTestCase):
         user = AutoAdminSingleton.objects.get().account
 
         user.set_password(TEST_ADMIN_USER_PASSWORD)
-        user.save(update_fields=['password'])
+        user.save(update_fields=('password',))
 
         self.assertEqual(AutoAdminSingleton.objects.get().account, None)
 
