@@ -1,5 +1,4 @@
 from django.apps import apps
-from django.db.models.signals import pre_save
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.acls.classes import ModelPermission
@@ -14,11 +13,10 @@ from mayan.apps.navigation.classes import SourceColumn
 
 from .dashboard_widgets import DashboardWidgetTotalCheckouts
 from .events import (
-    event_document_auto_check_in, event_document_check_in,
-    event_document_check_out, event_document_forceful_check_in
+    event_document_auto_checked_in, event_document_checked_in,
+    event_document_checked_out, event_document_forcefully_checked_in
 )
-from .handlers import handler_check_new_version_creation
-from .hooks import hook_is_new_version_allowed
+from .hooks import hook_is_new_file_allowed
 from .links import (
     link_check_in_document, link_check_in_document_multiple,
     link_check_out_document, link_check_out_document_multiple,
@@ -43,15 +41,15 @@ class CheckoutsApp(MayanAppConfig):
     verbose_name = _('Checkouts')
 
     def ready(self):
-        super(CheckoutsApp, self).ready()
+        super().ready()
 
         CheckedOutDocument = self.get_model(model_name='CheckedOutDocument')
         DocumentCheckout = self.get_model(model_name='DocumentCheckout')
         Document = apps.get_model(
             app_label='documents', model_name='Document'
         )
-        DocumentVersion = apps.get_model(
-            app_label='documents', model_name='DocumentVersion'
+        DocumentFile = apps.get_model(
+            app_label='documents', model_name='DocumentFile'
         )
 
         Document.add_to_class(name='check_in', value=method_check_in)
@@ -65,14 +63,14 @@ class CheckoutsApp(MayanAppConfig):
             name='is_checked_out', value=method_is_checked_out
         )
 
-        DocumentVersion.register_pre_save_hook(
-            func=hook_is_new_version_allowed
+        DocumentFile.register_pre_create_hook(
+            func=hook_is_new_file_allowed
         )
 
         ModelEventType.register(
             model=Document, event_types=(
-                event_document_auto_check_in, event_document_check_in,
-                event_document_check_out, event_document_forceful_check_in
+                event_document_auto_checked_in, event_document_checked_in,
+                event_document_checked_out, event_document_forcefully_checked_in
             )
         )
 
@@ -135,9 +133,3 @@ class CheckoutsApp(MayanAppConfig):
                 'checkouts:check_in_document'
             )
         )
-
-        pre_save.connect(
-            dispatch_uid='checkouts_handler_check_new_version_creation',
-            receiver=handler_check_new_version_creation,
-            sender=DocumentVersion
-        )
