@@ -10,7 +10,7 @@ def operation_move_from_content_type_user_to_foreign_key_field_user(apps, schema
         app_label='checkouts', model_name='DocumentCheckout'
     )
 
-    for document_checkout in DocumentCheckout.objects.using(schema_editor.connection.alias).all():
+    for document_checkout in DocumentCheckout.objects.using(alias=schema_editor.connection.alias).all():
         document_checkout.user = document_checkout.user_object
         document_checkout.save()
 
