@@ -3,7 +3,7 @@ from django.utils.encoding import force_text
 from rest_framework import status
 
 from mayan.apps.documents.permissions import permission_document_view
-from mayan.apps.documents.tests.mixins import DocumentTestMixin
+from mayan.apps.documents.tests.mixins.document_mixins import DocumentTestMixin
 from mayan.apps.rest_api.tests.base import BaseAPITestCase
 
 from ..permissions import (
@@ -20,6 +20,12 @@ class CheckoutsAPITestCase(
     DocumentCheckoutsAPIViewTestMixin, DocumentCheckoutTestMixin,
     DocumentTestMixin, BaseAPITestCase
 ):
+    auto_upload_test_document = False
+
+    def setUp(self):
+        super().setUp()
+        self._create_test_document_stub()
+
     def test_document_check_out_create_api_view_no_permission(self):
         response = self._request_test_document_check_out_create_api_view()
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
@@ -122,7 +128,7 @@ class CheckoutsAPITestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
             response.data['document']['uuid'],
-            force_text(self.test_document.uuid)
+            force_text(s=self.test_document.uuid)
         )
 
     def test_document_check_out_list_api_view_no_permission(self):
