@@ -1,15 +1,11 @@
-import time
-
 from mayan.apps.documents.tests.base import GenericDocumentTestCase
 from mayan.apps.documents.tests.literals import TEST_SMALL_DOCUMENT_PATH
-from mayan.apps.documents.tests.mixins import DocumentTestMixin
-from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..exceptions import (
     DocumentAlreadyCheckedOut, DocumentNotCheckedOut,
-    NewDocumentVersionNotAllowed
+    NewDocumentFileNotAllowed
 )
-from ..models import DocumentCheckout, NewVersionBlock
+from ..models import DocumentCheckout
 
 from .mixins import DocumentCheckoutTestMixin
 
@@ -17,6 +13,12 @@ from .mixins import DocumentCheckoutTestMixin
 class DocumentCheckoutTestCase(
     DocumentCheckoutTestMixin, GenericDocumentTestCase
 ):
+    auto_upload_test_document = False
+
+    def setUp(self):
+        super().setUp()
+        self._create_test_document_stub()
+
     def test_document_check_out(self):
         self._check_out_test_document()
 
@@ -47,7 +49,7 @@ class DocumentCheckoutTestCase(
                 document=self.test_document,
                 expiration_datetime=self._check_out_expiration_datetime,
                 user=self._test_case_superuser,
-                block_new_version=True
+                block_new_file=True
             )
 
     def test_document_check_in_without_check_out(self):
@@ -58,7 +60,7 @@ class DocumentCheckoutTestCase(
         self._check_out_test_document()
 
         # Ensure we wait from longer than the document check out expiration
-        time.sleep(self._test_document_check_out_seconds + 0.1)
+        self._test_delay(seconds=self._test_document_check_out_seconds + 0.1)
 
         DocumentCheckout.objects.check_in_expired_check_outs()
 
@@ -69,49 +71,16 @@ class DocumentCheckoutTestCase(
 
         self.assertTrue(self.test_check_out.get_absolute_url())
 
-
-class NewVersionBlockTestCase(
-    DocumentCheckoutTestMixin, DocumentTestMixin, BaseTestCase
-):
-    def test_blocking(self):
-        NewVersionBlock.objects.block(document=self.test_document)
-
-        self.assertEqual(NewVersionBlock.objects.count(), 1)
-        self.assertEqual(
-            NewVersionBlock.objects.first().document, self.test_document
-        )
-
-    def test_blocking_new_versions(self):
+    def test_blocking_new_files(self):
         # Silence unrelated logging
         self._silence_logger(name='mayan.apps.documents.models')
+        self._check_out_test_document()
 
-        NewVersionBlock.objects.block(document=self.test_document)
-
-        with self.assertRaises(expected_exception=NewDocumentVersionNotAllowed):
+        with self.assertRaises(expected_exception=NewDocumentFileNotAllowed):
             with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
-                self.test_document.new_version(file_object=file_object)
+                self.test_document.file_new(file_object=file_object)
 
-    def test_unblocking(self):
-        NewVersionBlock.objects.create(document=self.test_document)
-
-        NewVersionBlock.objects.unblock(document=self.test_document)
-
-        self.assertEqual(NewVersionBlock.objects.count(), 0)
-
-    def test_is_blocked(self):
-        NewVersionBlock.objects.create(document=self.test_document)
-
-        self.assertTrue(
-            NewVersionBlock.objects.is_blocked(document=self.test_document)
-        )
-
-        NewVersionBlock.objects.all().delete()
-
-        self.assertFalse(
-            NewVersionBlock.objects.is_blocked(document=self.test_document)
-        )
-
-    def test_version_creation_blocking(self):
+    def test_file_creation_blocking(self):
         # Silence unrelated logging
         self._silence_logger(name='mayan.apps.documents.models')
 
@@ -119,6 +88,6 @@ class NewVersionBlockTestCase(
 
         self._check_out_test_document()
 
-        with self.assertRaises(expected_exception=NewDocumentVersionNotAllowed):
+        with self.assertRaises(expected_exception=NewDocumentFileNotAllowed):
             with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
-                self.test_document.new_version(file_object=file_object)
+                self.test_document.file_new(file_object=file_object)
