@@ -1,10 +1,7 @@
-import hashlib
-
+from django.apps import apps
 from django.contrib import contenttypes
 from django.core.exceptions import ImproperlyConfigured
 from django.db import models
-from django.template.response import TemplateResponse
-from django.urls import reverse
 from django.utils.encoding import force_text
 from django.utils.translation import ugettext_lazy as _
 
@@ -15,7 +12,6 @@ from mayan.apps.acls.classes import ModelPermission
 from .links import link_object_copy
 from .menus import menu_object
 from .permissions import permission_object_copy
-from .settings import setting_home_view
 
 
 class ModelCopy:
@@ -37,8 +33,8 @@ class ModelCopy:
         return cls._registry[model]
 
     def __init__(
-        self, model, condition=None, bind_link=False, excludes=None, register_permission=False,
-        extra_kwargs=None
+        self, model, condition=None, bind_link=False, excludes=None,
+        register_permission=False, extra_kwargs=None
     ):
         self.condition = condition
         self.excludes = excludes or {}
@@ -72,6 +68,9 @@ class ModelCopy:
             self.add_fields(**entry)
             self.__class__._lazy.get(model).pop()
 
+    def __str__(self):
+        return force_text(s=self.label)
+
     def _evaluate_field_get_for_field(self, field, instance, value, values):
         context = {'instance': instance}
         context.update(values)
@@ -162,16 +161,16 @@ class ModelCopy:
 
         new_model_dictionary = {}
 
-        # Static values
+        # Static values.
         for field, value in self.field_values.items():
             new_model_dictionary[field] = value
 
-        # Static values templates
+        # Static values templates.
         for field, value in self.field_value_templates.items():
             result = value.format(**context) or None
             new_model_dictionary[field] = result
 
-        # Base fields whose values are copied
+        # Base fields whose values are copied.
         for field in self.fields_copy:
             value = values.get(field, getattr(instance, field))
 
@@ -180,7 +179,7 @@ class ModelCopy:
             )
             new_model_dictionary[field] = value
 
-        # Base fields with unique values
+        # Base fields with unique values.
         for field in self.fields_unique:
             base_value = getattr(instance, field)
             counter = 1
@@ -197,7 +196,7 @@ class ModelCopy:
             )
             new_model_dictionary[field] = value
 
-        # Foreign keys
+        # Foreign keys.
         for field in self.fields_foreign_keys:
             value = values.get(field, getattr(instance, field))
 
@@ -206,7 +205,7 @@ class ModelCopy:
             )
             new_model_dictionary[field] = value
 
-        # Fields that are given an unique value if a condition is met
+        # Fields that are given an unique value if a condition is met.
         for field in self.unique_conditional:
             if self.unique_conditional[field](
                 instance=instance, new_instance_dictionary=new_model_dictionary
@@ -234,15 +233,15 @@ class ModelCopy:
             new_instance = self.model(**new_model_dictionary)
             new_instance.save()
 
-        # Many to many fields added after instance creation
+        # Many to many fields added after instance creation.
         for field in self.fields_many_to_many:
             getattr(new_instance, field).set(getattr(instance, field).all())
 
-        # Many to many reverse related fields added after instance creation
+        # Many to many reverse related fields added after instance creation.
         for field in self.fields_many_to_many_reverse_related:
             getattr(new_instance, field).set(getattr(instance, field).all())
 
-        # Reverse related
+        # Reverse related.
         for field in self.fields_reverse_related:
             related_field = self.model._meta.get_field(field_name=field)
             related_field_name = related_field.field.name
@@ -253,7 +252,7 @@ class ModelCopy:
                     values=values
                 )
 
-        # Reverse related one to one
+        # Reverse related one to one.
         for field in self.fields_related_one_to_one:
             related_field = self.model._meta.get_field(field_name=field)
             related_field_name = related_field.field.name
@@ -262,7 +261,7 @@ class ModelCopy:
                 values={related_field_name: new_instance}
             )
 
-        # Generic relations
+        # Generic relations.
         for field in self.fields_generic_related:
             related_field = self.model._meta.get_field(field_name=field)
             related_field_name = 'content_object'
@@ -344,50 +343,6 @@ class PropertyHelper:
         raise NotImplementedError
 
 
-class Template:
-    _registry = {}
-
-    @classmethod
-    def all(cls, rendered=False, request=None):
-        if not rendered:
-            return cls._registry.values()
-        else:
-            result = []
-            for template in cls._registry.values():
-                result.append(template.render(request=request))
-            return result
-
-    @classmethod
-    def get(cls, name):
-        return cls._registry[name]
-
-    def __init__(self, name, template_name):
-        self.name = name
-        self.template_name = template_name
-        self.__class__._registry[name] = self
-
-    def get_absolute_url(self):
-        return reverse(
-            kwargs={'name': self.name}, viewname='rest_api:template-detail'
-        )
-
-    def render(self, request):
-        context = {
-            'home_view': setting_home_view.value,
-        }
-        result = TemplateResponse(
-            request=request,
-            template=self.template_name,
-            context=context,
-        ).render()
-
-        # Calculate the hash of the bytes version but return the unicode
-        # version
-        self.html = result.rendered_content.replace('\n', '')
-        self.hex_hash = hashlib.sha256(result.content).hexdigest()
-        return self
-
-
 class ModelAttribute:
     _class_registry = []
     _model_registry = {}
@@ -419,9 +374,9 @@ class ModelAttribute:
             return cls._model_registry[cls.class_name][model]
         except KeyError:
             # We were passed a model instance, try again using the model of
-            # the instance
+            # the instance.
 
-            # If we are already in the model class, exit with an error
+            # If we are already in the model class, exit with an error.
             if model.__class__ == models.base.ModelBase:
                 return []
 
@@ -446,7 +401,7 @@ class ModelAttribute:
                 self.name if show_name else self.label, self.description
             )
         else:
-            return force_text(self.name if show_name else self.label)
+            return force_text(s=self.name if show_name else self.label)
 
 
 class ModelProperty(ModelAttribute):
@@ -459,7 +414,7 @@ class ModelField(ModelAttribute):
     class_name = 'field'
 
     def __init__(self, *args, **kwargs):
-        super(ModelField, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._final_model_verbose_name = None
 
         if not self.label:
@@ -563,18 +518,96 @@ class ModelQueryFields:
             )
         self.prefetch_related_fields.append(field_name)
 
-    def get_queryset(self):
-        queryset = self.model._meta.default_manager.all()
+    def get_queryset(self, manager_name=None):
+        if manager_name:
+            manager = getattr(self.model, manager_name)
+        else:
+            manager = self.model._meta.default_manager
+
+        queryset = manager.all()
 
         if self.select_related_fields:
             queryset = queryset.select_related(*self.select_related_fields)
 
         if self.prefetch_related_fields:
-            queryset = queryset.prefetch_related(*self.prefetch_related_fields)
+            queryset = queryset.prefetch_related(
+                *self.prefetch_related_fields
+            )
 
         return queryset
 
 
+class QuerysetParametersSerializer:
+    @staticmethod
+    def decompose(_model, _method_name, _manager_name=None, **kwargs):
+        ContentType = apps.get_model(
+            app_label='contenttypes', model_name='ContentType'
+        )
+
+        _manager_name = _manager_name or _model._meta.default_manager.name
+
+        serialized_kwargs = []
+        for name, value in kwargs.items():
+            try:
+                content_type = ContentType.objects.get_for_model(model=value)
+            except AttributeError:
+                """The value is not a model instance, pass it as-is."""
+                serialized_kwargs.append(
+                    {
+                        'name': name,
+                        'value': value
+                    }
+                )
+            else:
+                serialized_kwargs.append(
+                    {
+                        'name': name,
+                        'content_type_id': content_type.pk,
+                        'object_id': value.pk
+                    }
+                )
+
+        return {
+            'model_content_type_id': ContentType.objects.get_for_model(
+                model=_model
+            ).pk,
+            'manager_name': _manager_name,
+            'method_name': _method_name,
+            'kwargs': serialized_kwargs
+        }
+
+    @staticmethod
+    def rebuild(decomposed_queryset):
+        ContentType = apps.get_model(
+            app_label='contenttypes', model_name='ContentType'
+        )
+
+        model = ContentType.objects.get(
+            pk=decomposed_queryset['model_content_type_id']
+        ).model_class()
+
+        queryset = getattr(model, decomposed_queryset['manager_name'])
+
+        kwargs = {}
+
+        for parameter in decomposed_queryset.get('kwargs', ()):
+            if 'content_type_id' in parameter:
+                content_type = ContentType.objects.get(
+                    pk=parameter['content_type_id']
+                )
+                value = content_type.get_object_for_this_type(
+                    pk=parameter['object_id']
+                )
+            else:
+                value = parameter['value']
+
+            kwargs[parameter['name']] = value
+
+        return getattr(
+            queryset, decomposed_queryset['method_name']
+        )(**kwargs)
+
+
 ModelAttribute.register(klass=ModelProperty)
 ModelAttribute.register(klass=ModelField)
 ModelAttribute.register(klass=ModelFieldRelated)
