@@ -6,19 +6,17 @@ from django.core import management
 from django.core.management.utils import get_random_secret_key
 
 import mayan
-from mayan.settings.literals import SECRET_KEY_FILENAME, SYSTEM_DIR
+from mayan.settings.literals import (
+    DEFAULT_USER_SETTINGS_FOLDER, SECRET_KEY_FILENAME, SYSTEM_DIR
+)
+from mayan.apps.storage.utils import touch
 
-from ...signals import post_initial_setup, pre_initial_setup
+from ...signals import signal_post_initial_setup, signal_pre_initial_setup
 
 
 class Command(management.BaseCommand):
     help = 'Initializes an install and gets it ready to be used.'
 
-    @staticmethod
-    def touch(filename, times=None):
-        with open(filename, 'a'):
-            os.utime(filename, times)
-
     def add_arguments(self, parser):
         parser.add_argument(
             '--force', action='store_true', dest='force',
@@ -32,42 +30,50 @@ class Command(management.BaseCommand):
 
     def initialize_system(self, force=False):
         system_path = os.path.join(settings.MEDIA_ROOT, SYSTEM_DIR)
-        settings_path = os.path.join(settings.MEDIA_ROOT, 'mayan_settings')
+        settings_path = os.path.join(
+            settings.MEDIA_ROOT, DEFAULT_USER_SETTINGS_FOLDER
+        )
         secret_key_file_path = os.path.join(system_path, SECRET_KEY_FILENAME)
 
-        if not os.path.exists(settings.MEDIA_ROOT) or force:
+        if not os.path.exists(path=settings.MEDIA_ROOT) or force:
             # Create the media folder
             try:
-                os.makedirs(settings.MEDIA_ROOT)
+                os.makedirs(name=settings.MEDIA_ROOT)
             except OSError as exception:
                 if exception.errno == errno.EEXIST and force:
-                    pass
+                    """Folder already exists. Ignore."""
+                else:
+                    raise
 
             # Touch media/__init__.py
-            Command.touch(os.path.join(settings.MEDIA_ROOT, '__init__.py'))
+            touch(os.path.join(settings.MEDIA_ROOT, '__init__.py'))
 
-            # Create media/settings
+            # Create user settings folder
             try:
-                os.makedirs(settings_path)
+                os.makedirs(name=settings_path)
             except OSError as exception:
                 if exception.errno == errno.EEXIST and force:
-                    pass
+                    """Folder already exists. Ignore."""
+                else:
+                    raise
 
             # Touch media/settings/__init__.py
-            Command.touch(os.path.join(settings_path, '__init__.py'))
+            touch(filename=os.path.join(settings_path, '__init__.py'))
 
             # Create the media/system folder
             try:
-                os.makedirs(system_path)
+                os.makedirs(name=system_path)
             except OSError as exception:
                 if exception.errno == errno.EEXIST and force:
-                    pass
+                    """Folder already exists. Ignore."""
+                else:
+                    raise
 
             version_file_path = os.path.join(system_path, 'VERSION')
-            with open(version_file_path, 'w') as file_object:
+            with open(file=version_file_path, mode='w') as file_object:
                 file_object.write(mayan.__version__)
 
-            with open(secret_key_file_path, 'w') as file_object:
+            with open(file=secret_key_file_path, mode='w') as file_object:
                 secret_key = get_random_secret_key()
                 file_object.write(secret_key)
 
@@ -84,7 +90,7 @@ class Command(management.BaseCommand):
 
     def handle(self, *args, **options):
         self.initialize_system(force=options.get('force', False))
-        pre_initial_setup.send(sender=self)
+        signal_pre_initial_setup.send(sender=self)
 
         if not options.get('no_dependencies', False):
             management.call_command(command_name='installdependencies')
@@ -93,4 +99,5 @@ class Command(management.BaseCommand):
             )
 
         management.call_command(command_name='createautoadmin')
-        post_initial_setup.send(sender=self)
+        management.call_command(command_name='savesettings')
+        signal_post_initial_setup.send(sender=self)
