@@ -15,14 +15,14 @@ def code_copy_transformations(apps, schema_editor):
     )
 
     stored_layer, created = StoredLayer.objects.using(
-        schema_editor.connection.alias
+        alias=schema_editor.connection.alias
     ).update_or_create(
         name=layer_saved_transformations.name, defaults={
             'order': layer_saved_transformations.order
         }
     )
 
-    for transformation in Transformation.objects.using(schema_editor.connection.alias).all():
+    for transformation in Transformation.objects.using(alias=schema_editor.connection.alias).all():
         object_layer, created = ObjectLayer.objects.get_or_create(
             content_type=transformation.content_type,
             object_id=transformation.object_id,
@@ -50,16 +50,16 @@ def code_copy_transformations_reverse(apps, schema_editor):
     )
 
     stored_layer, created = StoredLayer.objects.using(
-        schema_editor.connection.alias
+        alias=schema_editor.connection.alias
     ).update_or_create(
         name=layer_saved_transformations.name, defaults={
             'order': layer_saved_transformations.order
         }
     )
 
-    for object_layer in ObjectLayer.objects.using(schema_editor.connection.alias).filter(stored_layer=stored_layer):
-        for layer_transformation in LayerTransformation.objects.using(schema_editor.connection.alias).filter(object_layer=object_layer):
-            Transformation.objects.using(schema_editor.connection.alias).create(
+    for object_layer in ObjectLayer.objects.using(alias=schema_editor.connection.alias).filter(stored_layer=stored_layer):
+        for layer_transformation in LayerTransformation.objects.using(alias=schema_editor.connection.alias).filter(object_layer=object_layer):
+            Transformation.objects.using(alias=schema_editor.connection.alias).create(
                 content_type=object_layer.content_type,
                 object_id=object_layer.object_id,
                 order=layer_transformation.order,
