@@ -10,19 +10,24 @@ TEST_ASSET_PATH = os.path.join(
     'test_files', 'test_asset.png'
 )
 
-TEST_TRANSFORMATION_NAME = 'rotate'
+TEST_LAYER_LABEL = 'Test layer'
+TEST_LAYER_ORDER = 1000
+TEST_LAYER_NAME = 'test_layer'
+
 TEST_TRANSFORMATION_ARGUMENT = 'degrees: 180'
 TEST_TRANSFORMATION_ARGUMENT_EDITED = 'degrees: 270'
-TEST_TRANSFORMATION_CLASS_LABEL = 'Test transformation class'
-TEST_TRANSFORMATION_CLASS_NAME = 'test_transformation_class'
 TEST_TRANSFORMATION_COMBINED_CACHE_HASH = '384bf78014d2aed7255d9e548a0694c70af0b22545653214bcceb1ac6286b5f7'
+TEST_TRANSFORMATION_LABEL = 'Test transformation class'
+TEST_TRANSFORMATION_NAME = 'test_transformation_class'
 TEST_TRANSFORMATION_RESIZE_CACHE_HASH = b'4aa319f5a6950985a19380a1f279a66769d04138bd1583844270fe8c269260fc'
 TEST_TRANSFORMATION_RESIZE_CACHE_HASH_2 = b'cc8d220d40e810b995181c0c69b44b7a61c3bb039c0be96a5465fcaf698ca99a'
 TEST_TRANSFORMATION_RESIZE_HEIGHT = 528
 TEST_TRANSFORMATION_RESIZE_HEIGHT_2 = 529
 TEST_TRANSFORMATION_RESIZE_WIDTH = 123
 TEST_TRANSFORMATION_RESIZE_WIDTH_2 = 124
+TEST_TRANSFORMATION_ROTATE_ARGUMENT = 'degrees: 180'
 TEST_TRANSFORMATION_ROTATE_CACHE_HASH = b'df6a5854fccdd3a56145fcd7f7bf52bdf95fe940d6611d435e80dfcaca3b61ac'
 TEST_TRANSFORMATION_ROTATE_DEGRESS = 34
+TEST_TRANSFORMATION_ROTATE_NAME = 'rotate'
 TEST_TRANSFORMATION_ZOOM_CACHE_HASH = b'ac7a864de6a95889d5892301e142f8cdc5808f55010c0b820ed056902fc25a73'
 TEST_TRANSFORMATION_ZOOM_PERCENT = 49
