@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 from django.test import TestCase
 
 from mayan.apps.documents.tests.base import GenericDocumentTestCase
@@ -14,14 +12,11 @@ from .literals import (
     TEST_TRANSFORMATION_COMBINED_CACHE_HASH,
     TEST_TRANSFORMATION_RESIZE_CACHE_HASH,
     TEST_TRANSFORMATION_RESIZE_CACHE_HASH_2,
-    TEST_TRANSFORMATION_RESIZE_HEIGHT,
-    TEST_TRANSFORMATION_RESIZE_HEIGHT_2,
-    TEST_TRANSFORMATION_RESIZE_WIDTH,
-    TEST_TRANSFORMATION_RESIZE_WIDTH_2,
+    TEST_TRANSFORMATION_RESIZE_HEIGHT, TEST_TRANSFORMATION_RESIZE_HEIGHT_2,
+    TEST_TRANSFORMATION_RESIZE_WIDTH, TEST_TRANSFORMATION_RESIZE_WIDTH_2,
     TEST_TRANSFORMATION_ROTATE_CACHE_HASH,
-    TEST_TRANSFORMATION_ROTATE_DEGRESS,
-    TEST_TRANSFORMATION_ZOOM_CACHE_HASH,
-    TEST_TRANSFORMATION_ZOOM_PERCENT,
+    TEST_TRANSFORMATION_ROTATE_DEGRESS, TEST_TRANSFORMATION_ZOOM_CACHE_HASH,
+    TEST_TRANSFORMATION_ZOOM_PERCENT
 )
 from .mixins import LayerTestMixin
 
@@ -105,13 +100,22 @@ class TransformationBaseTestCase(TestCase):
 
         self.assertEqual(
             BaseTransformation.combine(
-                (transformation_rotate, transformation_resize, transformation_zoom)
+                (
+                    transformation_rotate, transformation_resize,
+                    transformation_zoom
+                )
             ), TEST_TRANSFORMATION_COMBINED_CACHE_HASH
         )
 
 
 class TransformationTestCase(LayerTestMixin, GenericDocumentTestCase):
+    auto_create_test_transformation_class = False
+
     def test_crop_transformation_optional_arguments(self):
+        BaseTransformation.register(
+            layer=self.test_layer, transformation=TransformationCrop
+        )
+
         self._silence_logger(name='mayan.apps.converter.managers')
 
         document_page = self.test_document.pages.first()
@@ -124,6 +128,10 @@ class TransformationTestCase(LayerTestMixin, GenericDocumentTestCase):
         self.assertTrue(document_page.generate_image())
 
     def test_crop_transformation_invalid_arguments(self):
+        BaseTransformation.register(
+            layer=self.test_layer, transformation=TransformationCrop
+        )
+
         self._silence_logger(name='mayan.apps.converter.managers')
 
         document_page = self.test_document.pages.first()
@@ -135,6 +143,10 @@ class TransformationTestCase(LayerTestMixin, GenericDocumentTestCase):
         self.assertTrue(document_page.generate_image())
 
     def test_crop_transformation_non_valid_range_arguments(self):
+        BaseTransformation.register(
+            layer=self.test_layer, transformation=TransformationCrop
+        )
+
         self._silence_logger(name='mayan.apps.converter.managers')
 
         document_page = self.test_document.pages.first()
@@ -147,6 +159,10 @@ class TransformationTestCase(LayerTestMixin, GenericDocumentTestCase):
         self.assertTrue(document_page.generate_image())
 
     def test_crop_transformation_overlapping_ranges_arguments(self):
+        BaseTransformation.register(
+            layer=self.test_layer, transformation=TransformationCrop
+        )
+
         self._silence_logger(name='mayan.apps.converter.managers')
 
         document_page = self.test_document.pages.first()
@@ -164,6 +180,10 @@ class TransformationTestCase(LayerTestMixin, GenericDocumentTestCase):
         self.assertTrue(document_page.generate_image())
 
     def test_lineart_transformations(self):
+        BaseTransformation.register(
+            layer=self.test_layer, transformation=TransformationLineArt
+        )
+
         document_page = self.test_document.pages.first()
 
         self.test_layer.add_transformation_to(
@@ -174,6 +194,10 @@ class TransformationTestCase(LayerTestMixin, GenericDocumentTestCase):
         self.assertTrue(document_page.generate_image())
 
     def test_rotate_transformations(self):
+        BaseTransformation.register(
+            layer=self.test_layer, transformation=TransformationRotate90
+        )
+
         document_page = self.test_document.pages.first()
 
         self.test_layer.add_transformation_to(
