@@ -1,8 +1,12 @@
 from django.conf.urls import url
 
+from .api_views import (
+    APIAppImageErrorImageView, APIAssetListView, APIAssetDetailView,
+    APIAssetImageView
+)
 from .views import (
-    AssetCreateView, AssetDeleteView, AssetEditView, AssetListView,
-    TransformationCreateView, TransformationDeleteView,
+    AssetCreateView, AssetDeleteView, AssetDetailView, AssetEditView,
+    AssetListView, TransformationCreateView, TransformationDeleteView,
     TransformationEditView, TransformationListView, TransformationSelectView
 )
 
@@ -19,6 +23,10 @@ urlpatterns_assets = [
         regex=r'^assets/(?P<asset_id>\d+)/delete/$',
         name='asset_single_delete', view=AssetDeleteView.as_view()
     ),
+    url(
+        regex=r'^assets/(?P<asset_id>\d+)/detail/$',
+        name='asset_detail', view=AssetDetailView.as_view()
+    ),
     url(
         regex=r'^assets/multiple/delete/$',
         name='asset_multiple_delete', view=AssetDeleteView.as_view()
@@ -55,3 +63,25 @@ urlpatterns_transformations = [
 urlpatterns = []
 urlpatterns.extend(urlpatterns_assets)
 urlpatterns.extend(urlpatterns_transformations)
+
+api_urls_assets = [
+    url(
+        regex=r'^app_image_error/(?P<app_image_error_name>[-\w]+)/image/$',
+        name='app-image-error-image', view=APIAppImageErrorImageView.as_view()
+    ),
+    url(
+        regex=r'^assets/$', name='asset-list',
+        view=APIAssetListView.as_view()
+    ),
+    url(
+        regex=r'^assets/(?P<asset_id>[0-9]+)/$',
+        name='asset-detail', view=APIAssetDetailView.as_view()
+    ),
+    url(
+        regex=r'^assets/(?P<asset_id>\d+)/image/$',
+        name='asset-image', view=APIAssetImageView.as_view()
+    ),
+]
+
+api_urls = []
+api_urls.extend(api_urls_assets)
