@@ -8,11 +8,14 @@ from django.utils.translation import ugettext_lazy as _, ungettext
 
 from mayan.apps.views.generics import (
     FormView, MultipleObjectConfirmActionView, SingleObjectCreateView,
-    SingleObjectDeleteView, SingleObjectEditView, SingleObjectListView
+    SingleObjectDeleteView, SingleObjectDetailView, SingleObjectEditView,
+    SingleObjectListView
 )
-from mayan.apps.views.mixins import ExternalContentTypeObjectMixin
+from mayan.apps.views.mixins import ExternalContentTypeObjectViewMixin
 
-from .forms import LayerTransformationForm, LayerTransformationSelectForm
+from .forms import (
+    AssetDetailForm, LayerTransformationForm, LayerTransformationSelectForm
+)
 from .icons import icon_asset_list
 from .links import link_asset_create, link_transformation_select
 from .models import Asset, LayerTransformation, ObjectLayer
@@ -88,6 +91,19 @@ class AssetDeleteView(MultipleObjectConfirmActionView):
             )
 
 
+class AssetDetailView(SingleObjectDetailView):
+    form_class = AssetDetailForm
+    model = Asset
+    object_permission = permission_asset_view
+    pk_url_kwarg = 'asset_id'
+
+    def get_extra_context(self):
+        return {
+            'object': self.object,
+            'title': _('Details asset: %s') % self.object,
+        }
+
+
 class AssetEditView(SingleObjectEditView):
     fields = ('label', 'internal_name', 'file')
     model = Asset
@@ -129,19 +145,20 @@ class AssetListView(SingleObjectListView):
 
 
 class TransformationCreateView(
-    LayerViewMixin, ExternalContentTypeObjectMixin, SingleObjectCreateView
+    LayerViewMixin, ExternalContentTypeObjectViewMixin, SingleObjectCreateView
 ):
     form_class = LayerTransformationForm
 
     def form_valid(self, form):
         object_layer, created = ObjectLayer.objects.get_for(
-            obj=self.external_object, layer=self.layer
+            layer=self.layer, obj=self.external_object
         )
 
         instance = form.save(commit=False)
         instance.content_object = self.external_object
         instance.name = self.kwargs['transformation_name']
         instance.object_layer = object_layer
+
         try:
             instance.full_clean()
             instance.save()
@@ -151,9 +168,9 @@ class TransformationCreateView(
                 message=_('Error creating transformation: %s.') % exception,
                 request=self.request
             )
-            return super(TransformationCreateView, self).form_invalid(form)
+            return super().form_invalid(form=form)
         else:
-            return super(TransformationCreateView, self).form_valid(form)
+            return super().form_valid(form=form)
 
     def get_extra_context(self):
         return {
@@ -256,9 +273,9 @@ class TransformationEditView(LayerViewMixin, SingleObjectEditView):
             instance.save()
         except Exception as exception:
             logger.debug('Invalid form, exception: %s', exception)
-            return super(TransformationEditView, self).form_invalid(form=form)
+            return super().form_invalid(form=form)
         else:
-            return super(TransformationEditView, self).form_valid(form=form)
+            return super().form_valid(form=form)
 
     def get_extra_context(self):
         return {
@@ -302,7 +319,7 @@ class TransformationEditView(LayerViewMixin, SingleObjectEditView):
 
 
 class TransformationListView(
-    LayerViewMixin, ExternalContentTypeObjectMixin, SingleObjectListView
+    LayerViewMixin, ExternalContentTypeObjectViewMixin, SingleObjectListView
 ):
     def get_external_object_permission(self):
         return self.layer.get_permission(action='view')
@@ -339,7 +356,7 @@ class TransformationListView(
 
 
 class TransformationSelectView(
-    LayerViewMixin, ExternalContentTypeObjectMixin, FormView
+    LayerViewMixin, ExternalContentTypeObjectViewMixin, FormView
 ):
     form_class = LayerTransformationSelectForm
     template_name = 'appearance/generic_form.html'
