@@ -10,7 +10,7 @@ class DependencyEnvironment:
         self.mark_missing = mark_missing
 
     def __str__(self):
-        return force_text(self.label)
+        return force_text(s=self.label)
 
 
 environment_build = DependencyEnvironment(
