@@ -1,27 +1,40 @@
+from django.db.models import Q
+
 from ..models import Key
 
 from .literals import TEST_KEY_PRIVATE_DATA, TEST_KEY_PUBLIC_FILE_PATH
 
 
 class KeyAPIViewTestMixin:
-    def _request_test_key_create_view(self):
-        return self.post(
+    def _request_test_key_create_api_view(self):
+        pk_list = list(Key.objects.values_list('pk', flat=True))
+
+        response = self.post(
             viewname='rest_api:key-list', data={
                 'key_data': TEST_KEY_PRIVATE_DATA
             }
         )
 
-    def _request_test_key_delete_view(self):
+        try:
+            self.test_key_private = Key.objects.get(
+                ~Q(pk__in=pk_list)
+            )
+        except Key.DoesNotExist:
+            self.test_key_private = None
+
+        return response
+
+    def _request_test_key_delete_api_view(self):
         return self.delete(
             viewname='rest_api:key-detail', kwargs={
-                'pk': self.test_key_private.pk
+                'key_id': self.test_key_private.pk
             }
         )
 
-    def _request_test_key_detail_view(self):
+    def _request_test_key_detail_api_view(self):
         return self.get(
             viewname='rest_api:key-detail', kwargs={
-                'pk': self.test_key_private.pk
+                'key_id': self.test_key_private.pk
             }
         )
 
@@ -40,6 +53,13 @@ class KeyTestMixin:
 
 
 class KeyViewTestMixin:
+    def _request_test_key_delete_view(self):
+        return self.post(
+            viewname='django_gpg:key_delete', kwargs={
+                'key_id': self.test_key_private.pk
+            }
+        )
+
     def _request_test_key_download_view(self):
         return self.get(
             viewname='django_gpg:key_download', kwargs={
@@ -48,8 +68,19 @@ class KeyViewTestMixin:
         )
 
     def _request_test_key_upload_view(self):
-        return self.post(
+        pk_list = list(Key.objects.values_list('pk', flat=True))
+
+        response = self.post(
             viewname='django_gpg:key_upload', data={
                 'key_data': TEST_KEY_PRIVATE_DATA
             }
         )
+
+        try:
+            self.test_key_private = Key.objects.get(
+                ~Q(pk__in=pk_list)
+            )
+        except Key.DoesNotExist:
+            self.test_key_private = None
+
+        return response
