@@ -6,9 +6,12 @@ from .mixins import DocumentCommentTestMixin
 class DocumentCommentModelTestCase(
     DocumentCommentTestMixin, GenericDocumentViewTestCase
 ):
+    auto_upload_test_document = False
+
     def setUp(self):
         super().setUp()
         self._create_test_user()
+        self._create_test_document_stub()
 
     def test_method_get_absolute_url(self):
         self._create_test_comment()
