@@ -1,28 +1,29 @@
 from mayan.apps.appearance.classes import Icon
 
-icon_document_content = Icon(driver_name='fontawesome', symbol='font')
-icon_document_content_delete = Icon(
+icon_document_file_content = Icon(driver_name='fontawesome', symbol='font')
+icon_document_file_content_delete = Icon(
     driver_name='fontawesome-dual', primary_symbol='font',
     secondary_symbol='times'
 )
-icon_document_parsing_errors_list = Icon(
-    driver_name='fontawesome-dual', primary_symbol='font',
-    secondary_symbol='exclamation'
-)
-icon_document_content_download = Icon(
+icon_document_file_content_download = Icon(
     driver_name='fontawesome-dual', primary_symbol='font',
     secondary_symbol='arrow-down'
 )
+icon_document_file_page_content = icon_document_file_content
 icon_document_multiple_submit = Icon(
     driver_name='fontawesome-dual', primary_symbol='font',
     secondary_symbol='arrow-right'
 )
-icon_document_submit = icon_document_multiple_submit
+icon_document_file_parsing_errors_list = Icon(
+    driver_name='fontawesome-dual', primary_symbol='font',
+    secondary_symbol='exclamation'
+)
+icon_document_file_submit = icon_document_multiple_submit
 icon_document_type_parsing_settings = Icon(
     driver_name='fontawesome', symbol='font'
 )
 icon_document_type_submit = icon_document_multiple_submit
-icon_link_error_list = Icon(
+icon_error_list = Icon(
     driver_name='fontawesome-dual', primary_symbol='font',
     secondary_symbol='exclamation'
 )
