@@ -1,3 +1,8 @@
+from ..models import DocumentFilePageContent
+
+from .literals import TEST_DOCUMENT_CONTENT
+
+
 class DocumentFileContentToolsViewsTestMixin:
     def _request_document_parsing_error_list_view(self):
         return self.get(viewname='document_parsing:error_list')
@@ -10,6 +15,18 @@ class DocumentFileContentToolsViewsTestMixin:
         )
 
 
+class DocumentFileContentTestMixin:
+    def setUp(self):
+        super().setUp()
+        self._create_test_document_file_parsed_content()
+
+    def _create_test_document_file_parsed_content(self):
+        DocumentFilePageContent.objects.create(
+            document_file_page=self.test_document_file_page,
+            content=TEST_DOCUMENT_CONTENT
+        )
+
+
 class DocumentFileContentViewTestMixin:
     def _request_test_document_file_content_delete_view(self):
         return self.post(
