@@ -3,6 +3,10 @@ from django.test import override_settings
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
 from mayan.apps.documents.tests.literals import TEST_HYBRID_DOCUMENT
 
+from ..events import (
+    event_parsing_document_file_content_deleted,
+    event_parsing_document_file_finished, event_parsing_document_file_submitted
+)
 from ..models import DocumentFilePageContent
 from ..permissions import (
     permission_document_file_content_view, permission_document_file_parse,
@@ -12,35 +16,43 @@ from ..utils import get_document_file_content
 
 from .literals import TEST_DOCUMENT_CONTENT
 from .mixins import (
-    DocumentFileContentToolsViewsTestMixin, DocumentFileContentViewTestMixin,
-    DocumentTypeContentViewsTestMixin
+    DocumentFileContentTestMixin, DocumentFileContentToolsViewsTestMixin,
+    DocumentFileContentViewTestMixin, DocumentTypeContentViewsTestMixin
 )
 
 
-@override_settings(DOCUMENT_PARSING_AUTO_PARSING=True)
 class DocumentFileContentViewsTestCase(
-    DocumentFileContentViewTestMixin, GenericDocumentViewTestCase
+    DocumentFileContentViewTestMixin, DocumentFileContentTestMixin,
+    GenericDocumentViewTestCase
 ):
-    _skip_file_descriptor_test = True
-    # Ensure we use a PDF file
-    test_document_filename = TEST_HYBRID_DOCUMENT
-
     def test_document_file_content_view_no_permission(self):
+        self._clear_events()
+
         response = self._request_test_document_file_content_view()
         self.assertEqual(response.status_code, 404)
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_file_content_view_with_access(self):
         self.grant_access(
             obj=self.test_document,
             permission=permission_document_file_content_view
         )
 
+        self._clear_events()
+
         response = self._request_test_document_file_content_view()
         self.assertContains(
             response=response, text=TEST_DOCUMENT_CONTENT, status_code=200
         )
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_file_content_delete_view_no_permission(self):
+        self._clear_events()
+
         response = self._request_test_document_file_content_delete_view()
         self.assertEqual(response.status_code, 404)
 
@@ -50,11 +62,16 @@ class DocumentFileContentViewsTestCase(
             ).exists()
         )
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_file_content_delete_view_with_access(self):
         self.grant_access(
             obj=self.test_document, permission=permission_document_file_parse
         )
 
+        self._clear_events()
+
         response = self._request_test_document_file_content_delete_view()
         self.assertEqual(response.status_code, 302)
 
@@ -64,20 +81,41 @@ class DocumentFileContentViewsTestCase(
             ).exists()
         )
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 1)
+
+        self.assertEqual(events[0].actor, self._test_case_user)
+        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].target, self.test_document_file)
+        self.assertEqual(
+            events[0].verb, event_parsing_document_file_content_deleted.id
+        )
+
     def test_document_file_page_content_view_no_permission(self):
+        self._clear_events()
+
         response = self._request_test_document_file_page_content_view()
         self.assertEqual(response.status_code, 404)
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_file_page_content_view_with_access(self):
         self.grant_access(
             obj=self.test_document,
             permission=permission_document_file_content_view
         )
+
+        self._clear_events()
+
         response = self._request_test_document_file_page_content_view()
         self.assertContains(
             response=response, text=TEST_DOCUMENT_CONTENT, status_code=200
         )
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_trashed_document_file_page_content_view_with_access(self):
         self.grant_access(
             obj=self.test_document,
@@ -86,13 +124,70 @@ class DocumentFileContentViewsTestCase(
 
         self.test_document.delete()
 
+        self._clear_events()
+
         response = self._request_test_document_file_page_content_view()
         self.assertEqual(response.status_code, 404)
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
+    def test_document_file_parsing_error_list_view_no_permission(self):
+        self._clear_events()
+
+        response = self._request_test_document_file_parsing_error_list_view()
+
+        self.assertEqual(response.status_code, 404)
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
+    def test_document_file_parsing_error_list_view_with_access(self):
+        self.grant_access(
+            obj=self.test_document, permission=permission_document_file_parse
+        )
+
+        self._clear_events()
+
+        response = self._request_test_document_file_parsing_error_list_view()
+        self.assertEqual(response.status_code, 200)
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
+    def test_trashed_document_file_parsing_error_list_view_with_access(self):
+        self.grant_access(
+            obj=self.test_document, permission=permission_document_file_parse
+        )
+
+        self.test_document.delete()
+
+        self._clear_events()
+
+        response = self._request_test_document_file_parsing_error_list_view()
+        self.assertEqual(response.status_code, 404)
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
+
+@override_settings(DOCUMENT_PARSING_AUTO_PARSING=True)
+class DocumentFileContentParsingViewsTestCase(
+    DocumentFileContentViewTestMixin, GenericDocumentViewTestCase
+):
+    _skip_file_descriptor_test = True
+    # Ensure we use a PDF file.
+    test_document_filename = TEST_HYBRID_DOCUMENT
+
     def test_document_file_parsing_download_view_no_permission(self):
+        self._clear_events()
+
         response = self._request_test_document_file_content_download_view()
         self.assertEqual(response.status_code, 404)
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_file_parsing_download_view_with_access(self):
         self.expected_content_types = ('text/html; charset=utf-8',)
         self.grant_access(
@@ -100,6 +195,8 @@ class DocumentFileContentViewsTestCase(
             permission=permission_document_file_content_view
         )
 
+        self._clear_events()
+
         response = self._request_test_document_file_content_download_view()
         self.assertEqual(response.status_code, 200)
 
@@ -113,6 +210,9 @@ class DocumentFileContentViewsTestCase(
             ),
         )
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_trashed_document_file_parsing_download_view_with_access(self):
         self.grant_access(
             obj=self.test_document,
@@ -121,44 +221,50 @@ class DocumentFileContentViewsTestCase(
 
         self.test_document.delete()
 
+        self._clear_events()
+
         response = self._request_test_document_file_content_download_view()
         self.assertEqual(response.status_code, 404)
 
-    def test_document_file_parsing_error_list_view_no_permission(self):
-        response = self._request_test_document_file_parsing_error_list_view()
-
-        self.assertEqual(response.status_code, 404)
-
-    def test_document_file_parsing_error_list_view_with_access(self):
-        self.grant_access(
-            obj=self.test_document, permission=permission_document_file_parse
-        )
-
-        response = self._request_test_document_file_parsing_error_list_view()
-        self.assertEqual(response.status_code, 200)
-
-    def test_trashed_document_file_parsing_error_list_view_with_access(self):
-        self.grant_access(
-            obj=self.test_document, permission=permission_document_file_parse
-        )
-
-        self.test_document.delete()
-
-        response = self._request_test_document_file_parsing_error_list_view()
-        self.assertEqual(response.status_code, 404)
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
 
     def test_document_file_parsing_submit_view_no_permission(self):
+        self._clear_events()
+
         response = self._request_test_document_file_parsing_submit_view()
         self.assertEqual(response.status_code, 404)
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_file_parsing_submit_view_with_access(self):
         self.grant_access(
             obj=self.test_document, permission=permission_document_file_parse
         )
 
+        self._clear_events()
+
         response = self._request_test_document_file_parsing_submit_view()
         self.assertEqual(response.status_code, 302)
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 2)
+
+        self.assertEqual(events[0].actor, self._test_case_user)
+        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].target, self.test_document_file)
+        self.assertEqual(
+            events[0].verb, event_parsing_document_file_submitted.id
+        )
+
+        self.assertEqual(events[1].actor, self._test_case_user)
+        self.assertEqual(events[1].action_object, self.test_document)
+        self.assertEqual(events[1].target, self.test_document_file)
+        self.assertEqual(
+            events[1].verb, event_parsing_document_file_finished.id
+        )
+
     def test_trashed_document_file_parsing_submit_view_with_access(self):
         self.grant_access(
             obj=self.test_document, permission=permission_document_file_parse
@@ -166,9 +272,14 @@ class DocumentFileContentViewsTestCase(
 
         self.test_document.delete()
 
+        self._clear_events()
+
         response = self._request_test_document_file_parsing_submit_view()
         self.assertEqual(response.status_code, 404)
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
 
 class DocumentTypeParsingViewsTestCase(
     DocumentFileContentToolsViewsTestMixin, GenericDocumentViewTestCase
@@ -189,18 +300,30 @@ class DocumentTypeParsingViewsTestCase(
         )
 
     def test_document_parsing_error_list_view_no_permission(self):
+        self._clear_events()
+
         response = self._request_document_parsing_error_list_view()
         self.assertEqual(response.status_code, 403)
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_parsing_error_list_view_with_permission(self):
         self.grant_permission(permission=permission_document_file_parse)
 
+        self._clear_events()
+
         response = self._request_document_parsing_error_list_view()
         self.assertEqual(response.status_code, 200)
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_type_parsing_view_no_permission(self):
         self._upload_test_document()
 
+        self._clear_events()
+
         response = self._request_document_type_parsing_view()
         self.assertEqual(response.status_code, 200)
         self.assertNotContains(
@@ -212,11 +335,16 @@ class DocumentTypeParsingViewsTestCase(
             self._get_document_file_content(), TEST_DOCUMENT_CONTENT
         )
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_type_parsing_view_with_permission(self):
         self.grant_permission(permission=permission_document_file_parse)
 
         self._upload_test_document()
 
+        self._clear_events()
+
         response = self._request_document_type_parsing_view()
         self.assertEqual(response.status_code, 302)
 
@@ -224,6 +352,23 @@ class DocumentTypeParsingViewsTestCase(
             self._get_document_file_content(), TEST_DOCUMENT_CONTENT
         )
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 2)
+
+        self.assertEqual(events[0].actor, self._test_case_user)
+        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].target, self.test_document_file)
+        self.assertEqual(
+            events[0].verb, event_parsing_document_file_submitted.id
+        )
+
+        self.assertEqual(events[1].actor, self._test_case_user)
+        self.assertEqual(events[1].action_object, self.test_document)
+        self.assertEqual(events[1].target, self.test_document_file)
+        self.assertEqual(
+            events[1].verb, event_parsing_document_file_finished.id
+        )
+
 
 class DocumentTypeContentViewsTestCase(
     DocumentTypeContentViewsTestMixin, GenericDocumentViewTestCase
@@ -231,14 +376,24 @@ class DocumentTypeContentViewsTestCase(
     auto_upload_test_document = False
 
     def test_document_type_parsing_settings_view_no_permission(self):
+        self._clear_events()
+
         response = self._request_test_document_type_parsing_settings_view()
         self.assertEqual(response.status_code, 404)
 
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_type_parsing_settings_view_with_access(self):
         self.grant_access(
             obj=self.test_document_type,
             permission=permission_document_type_parsing_setup
         )
 
+        self._clear_events()
+
         response = self._request_test_document_type_parsing_settings_view()
         self.assertEqual(response.status_code, 200)
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
