@@ -6,16 +6,16 @@ from .models import DetachedSignature, EmbeddedSignature
 @admin.register(DetachedSignature)
 class DetachedSignatureAdmin(admin.ModelAdmin):
     list_display = (
-        'document_version', 'date', 'key_id', 'signature_id',
+        'document_file', 'date_time', 'key_id', 'signature_id',
         'public_key_fingerprint', 'signature_file'
     )
-    list_display_links = ('document_version',)
+    list_display_links = ('document_file',)
 
 
 @admin.register(EmbeddedSignature)
 class EmbeddedSignatureAdmin(admin.ModelAdmin):
     list_display = (
-        'document_version', 'date', 'key_id', 'signature_id',
+        'document_file', 'date_time', 'key_id', 'signature_id',
         'public_key_fingerprint'
     )
-    list_display_links = ('document_version',)
+    list_display_links = ('document_file',)
