@@ -2,10 +2,10 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.common.queues import queue_tools
 from mayan.apps.task_manager.classes import CeleryQueue
-from mayan.apps.task_manager.workers import worker_medium
+from mayan.apps.task_manager.workers import worker_c
 
 queue_signatures = CeleryQueue(
-    label=_('Signatures'), name='signatures', worker=worker_medium
+    label=_('Signatures'), name='signatures', worker=worker_c
 )
 
 queue_signatures.add_task_type(
@@ -17,11 +17,15 @@ queue_signatures.add_task_type(
     label=_('Unverify key signatures')
 )
 queue_signatures.add_task_type(
-    dotted_path='mayan.apps.document_signatures.tasks.task_verify_document_version',
-    label=_('Verify document version')
+    dotted_path='mayan.apps.document_signatures.tasks.task_verify_document_file',
+    label=_('Verify document file')
 )
 
 queue_tools.add_task_type(
     dotted_path='mayan.apps.document_signatures.tasks.task_verify_missing_embedded_signature',
     label=_('Verify missing embedded signature')
 )
+queue_tools.add_task_type(
+    dotted_path='mayan.apps.document_signatures.tasks.task_refresh_signature_information',
+    label=_('Refresh existing signature information')
+)
