@@ -29,7 +29,7 @@ class WorkflowActionMetaclass(type):
     _registry = {}
 
     def __new__(mcs, name, bases, attrs):
-        new_class = super(WorkflowActionMetaclass, mcs).__new__(
+        new_class = super().__new__(
             mcs, name, bases, attrs
         )
 
@@ -114,6 +114,9 @@ class WorkflowAction(
     def __init__(self, form_data=None):
         self.form_data = form_data
 
+    def execute(self, context):
+        raise NotImplementedError
+
     def get_form_schema(self, workflow_state, request=None):
         result = {
             'fields': self.fields or {},
