@@ -1,7 +1,6 @@
-
 class WorkflowException(Exception):
     """Base exception for the document states app"""
 
 
 class WorkflowStateActionError(WorkflowException):
-    """Raise for errors during exection of workflow state actions"""
+    """Raise for errors during execution of workflow state actions"""
