@@ -1,22 +1,19 @@
 from django.contrib import messages
-from django.db import transaction
 from django.template import RequestContext
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _, ungettext
+from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.acls.models import AccessControlList
-from mayan.apps.documents.events import event_document_type_edited
 from mayan.apps.documents.models.document_models import Document
 from mayan.apps.documents.models.document_type_models import DocumentType
 from mayan.apps.documents.permissions import permission_document_type_edit
 from mayan.apps.views.generics import (
     AddRemoveView, ConfirmView, MultipleObjectFormActionView,
-    MultipleObjectConfirmActionView, SingleObjectCreateView,
-    SingleObjectDetailView, SingleObjectEditView, SingleObjectListView
+    MultipleObjectDeleteView, SingleObjectCreateView, SingleObjectDetailView,
+    SingleObjectEditView, SingleObjectListView
 )
-from mayan.apps.views.mixins import ExternalObjectMixin
+from mayan.apps.views.mixins import ExternalObjectViewMixin
 
-from ..events import event_workflow_edited
 from ..forms import (
     WorkflowForm, WorkflowMultipleSelectionForm, WorkflowPreviewForm
 )
@@ -24,9 +21,9 @@ from ..icons import icon_workflow_template_list
 from ..links import link_workflow_template_create
 from ..models import Workflow
 from ..permissions import (
-    permission_workflow_create, permission_workflow_delete,
-    permission_workflow_edit, permission_workflow_tools,
-    permission_workflow_view,
+    permission_workflow_template_create, permission_workflow_template_delete,
+    permission_workflow_template_edit, permission_workflow_tools,
+    permission_workflow_template_view,
 )
 from ..tasks import (
     task_launch_all_workflows, task_launch_workflow, task_launch_workflow_for
@@ -38,13 +35,27 @@ class DocumentTypeWorkflowTemplatesView(AddRemoveView):
     main_object_model = DocumentType
     main_object_pk_url_kwarg = 'document_type_id'
     secondary_object_model = Workflow
-    secondary_object_permission = permission_workflow_edit
+    secondary_object_permission = permission_workflow_template_edit
     list_available_title = _('Available workflows')
     list_added_title = _('Workflows assigned this document type')
     related_field = 'workflows'
 
+    def action_add(self, queryset, _event_actor):
+        for workflow_template in queryset.all():
+            workflow_template._event_actor = _event_actor
+            workflow_template.document_types_add(
+                queryset=DocumentType.objects.filter(pk=self.main_object.pk)
+            )
+
+    def action_remove(self, queryset, _event_actor):
+        for workflow_template in queryset.all():
+            workflow_template._event_actor = _event_actor
+            workflow_template.document_types_remove(
+                queryset=DocumentType.objects.filter(pk=self.main_object.pk)
+            )
+
     def get_actions_extra_kwargs(self):
-        return {'_user': self.request.user}
+        return {'_event_actor': self.request.user}
 
     def get_extra_context(self):
         return {
@@ -58,72 +69,32 @@ class DocumentTypeWorkflowTemplatesView(AddRemoveView):
             ) % self.main_object,
         }
 
-    def action_add(self, queryset, _user):
-        with transaction.atomic():
-            event_document_type_edited.commit(
-                actor=_user, target=self.main_object
-            )
-
-            for obj in queryset:
-                self.main_object.workflows.add(obj)
-                event_workflow_edited.commit(
-                    action_object=self.main_object, actor=_user, target=obj
-                )
-
-    def action_remove(self, queryset, _user):
-        with transaction.atomic():
-            event_document_type_edited.commit(
-                actor=_user, target=self.main_object
-            )
-
-            for obj in queryset:
-                self.main_object.workflows.remove(obj)
-                event_workflow_edited.commit(
-                    action_object=self.main_object, actor=_user,
-                    target=obj
-                )
-                obj.instances.filter(
-                    document__document_type=self.main_object
-                ).delete()
-
 
 class DocumentWorkflowTemplatesLaunchView(MultipleObjectFormActionView):
+    error_message = _(
+        'Error launching workflows for document "%(instance)s"; %(exception)s'
+    )
     form_class = WorkflowMultipleSelectionForm
-    model = Document
     object_permission = permission_workflow_tools
     pk_url_kwarg = 'document_id'
-    success_message = _('Workflows launched for %(count)d document')
-    success_message_plural = _('Workflows launched for %(count)d documents')
+    source_queryset = Document.valid
+    success_message_single = _('Workflows launched successfully for document "%(object)s".')
+    success_message_singular = _('Workflows launched successfully for %(count)d document.')
+    success_message_plural = _('Workflows launched successfully for %(count)d documents.')
+    title_single = _('Launch workflow: %(object)s.')
+    title_singular = _('Launch workflows for the selected %(count)d document.')
+    title_plural = _('Launch workflows for the selected %(count)d documents.')
 
     def get_extra_context(self):
-        result = {
+        return {
             'submit_label': _('Launch'),
             'subtitle': _(
                 'Workflows already launched or workflows not applicable to '
                 'some documents when multiple documents are selected, '
                 'will be silently ignored.'
             ),
-            'title': ungettext(
-                singular='Launch selected workflows for %(count)d document',
-                plural='Launch selected workflows for %(count)d documents',
-                number=self.object_list.count()
-            ) % {
-                'count': self.object_list.count(),
-            }
         }
 
-        if self.object_list.count() == 1:
-            result.update(
-                {
-                    'object': self.object_list.first(),
-                    'title': _(
-                        'Launch selected workflows for document: %s'
-                    ) % self.object_list.first()
-                }
-            )
-
-        return result
-
     def get_form_extra_kwargs(self):
         workflows_union = Workflow.objects.filter(
             document_types__in=self.object_list.values('document_type')
@@ -159,65 +130,42 @@ class WorkflowTemplateCreateView(SingleObjectCreateView):
     post_action_redirect = reverse_lazy(
         viewname='document_states:workflow_template_list'
     )
-    view_permission = permission_workflow_create
+    view_permission = permission_workflow_template_create
 
-    def get_save_extra_data(self):
-        return {'_user': self.request.user}
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
 
 
-class WorkflowTemplateDeleteView(MultipleObjectConfirmActionView):
+class WorkflowTemplateDeleteView(MultipleObjectDeleteView):
+    error_message = _('Error deleting workflow "%(instance)s"; %(exception)s')
     model = Workflow
-    object_permission = permission_workflow_delete
+    object_permission = permission_workflow_template_delete
     pk_url_kwarg = 'workflow_template_id'
     post_action_redirect = reverse_lazy(
         viewname='document_states:workflow_template_list'
     )
-    success_message = _('Delete request performed on %(count)d workflow')
-    success_message_plural = _(
-        'Delete request performed on %(count)d workflows'
-    )
+    success_message_single = _('Workflow "%(object)s" deleted successfully.')
+    success_message_singular = _('%(count)d workflow deleted successfully.')
+    success_message_plural = _('%(count)d workflows deleted successfully.')
+    title_single = _('Delete workflow: %(object)s.')
+    title_singular = _('Delete the %(count)d selected workflow.')
+    title_plural = _('Delete the %(count)d selected workflows.')
 
     def get_extra_context(self):
-        result = {
-            'delete_view': True,
-            'message': _('All workflow instances will also be deleted.'),
-            'title': ungettext(
-                singular='Delete the selected workflow?',
-                plural='Delete the selected workflows?',
-                number=self.object_list.count()
-            )
+        return {
+            'message': _('All workflow instances will also be deleted.')
         }
 
-        if self.object_list.count() == 1:
-            result.update(
-                {
-                    'object': self.object_list.first(),
-                    'title': _('Delete workflow: %s?') % self.object_list.first()
-                }
-            )
-
-        return result
-
     def object_action(self, instance, form=None):
-        try:
-            instance.delete()
-            messages.success(
-                message=_(
-                    'Workflow "%s" deleted successfully.'
-                ) % instance, request=self.request
-            )
-        except Exception as exception:
-            messages.error(
-                message=_('Error deleting workflow "%(workflow)s": %(error)s') % {
-                    'workflow': instance, 'error': exception
-                }, request=self.request
-            )
+        instance.delete()
 
 
 class WorkflowTemplateEditView(SingleObjectEditView):
     form_class = WorkflowForm
     model = Workflow
-    object_permission = permission_workflow_edit
+    object_permission = permission_workflow_template_edit
     pk_url_kwarg = 'workflow_template_id'
     post_action_redirect = reverse_lazy(
         viewname='document_states:workflow_template_list'
@@ -230,13 +178,17 @@ class WorkflowTemplateEditView(SingleObjectEditView):
             ) % self.object,
         }
 
-    def get_save_extra_data(self):
-        return {'_user': self.request.user}
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
 
 
 class WorkflowTemplateDocumentTypesView(AddRemoveView):
-    main_object_permission = permission_workflow_edit
+    main_object_method_add_name = 'document_types_add'
+    main_object_method_remove_name = 'document_types_remove'
     main_object_model = Workflow
+    main_object_permission = permission_workflow_template_edit
     main_object_pk_url_kwarg = 'workflow_template_id'
     secondary_object_model = DocumentType
     secondary_object_permission = permission_document_type_edit
@@ -245,7 +197,7 @@ class WorkflowTemplateDocumentTypesView(AddRemoveView):
     related_field = 'document_types'
 
     def get_actions_extra_kwargs(self):
-        return {'_user': self.request.user}
+        return {'_event_actor': self.request.user}
 
     def get_extra_context(self):
         return {
@@ -260,36 +212,8 @@ class WorkflowTemplateDocumentTypesView(AddRemoveView):
             ) % self.main_object,
         }
 
-    def action_add(self, queryset, _user):
-        with transaction.atomic():
-            event_workflow_edited.commit(
-                actor=_user, target=self.main_object
-            )
 
-            for obj in queryset:
-                self.main_object.document_types.add(obj)
-                event_document_type_edited.commit(
-                    action_object=self.main_object, actor=_user, target=obj
-                )
-
-    def action_remove(self, queryset, _user):
-        with transaction.atomic():
-            event_workflow_edited.commit(
-                actor=_user, target=self.main_object
-            )
-
-            for obj in queryset:
-                self.main_object.document_types.remove(obj)
-                event_document_type_edited.commit(
-                    action_object=self.main_object, actor=_user,
-                    target=obj
-                )
-                self.main_object.instances.filter(
-                    document__document_type=obj
-                ).delete()
-
-
-class WorkflowTemplateLaunchView(ExternalObjectMixin, ConfirmView):
+class WorkflowTemplateLaunchView(ExternalObjectViewMixin, ConfirmView):
     external_object_class = Workflow
     external_object_permission = permission_workflow_tools
     external_object_pk_url_kwarg = 'workflow_template_id'
@@ -317,7 +241,7 @@ class WorkflowTemplateLaunchView(ExternalObjectMixin, ConfirmView):
 
 class WorkflowTemplateListView(SingleObjectListView):
     model = Workflow
-    object_permission = permission_workflow_view
+    object_permission = permission_workflow_template_view
 
     def get_extra_context(self):
         return {
@@ -341,7 +265,7 @@ class WorkflowTemplateListView(SingleObjectListView):
 class WorkflowTemplatePreviewView(SingleObjectDetailView):
     form_class = WorkflowPreviewForm
     model = Workflow
-    object_permission = permission_workflow_view
+    object_permission = permission_workflow_template_view
     pk_url_kwarg = 'workflow_template_id'
 
     def get_extra_context(self):
