@@ -39,7 +39,7 @@ class APIDocumentFileListView(
     get: Return a list of the selected document's files.
     post: Create a new document file.
     """
-    ordering_fields = ('comment', 'encoding', 'mime_type',)
+    ordering_fields = ('comment', 'encoding', 'id', 'mime_type')
     serializer_class = DocumentFileSerializer
 
     def create(self, request, *args, **kwargs):
@@ -186,9 +186,11 @@ class APIDocumentFilePageImageView(
         if maximum_layer_order:
             maximum_layer_order = int(maximum_layer_order)
 
+        obj = self.get_object()
+
         task = task_document_file_page_image_generate.apply_async(
             kwargs={
-                'document_file_page_id': self.get_object().pk,
+                'document_file_page_id': obj.pk,
                 'height': height,
                 'maximum_layer_order': maximum_layer_order,
                 'rotation': rotation,
@@ -206,9 +208,9 @@ class APIDocumentFilePageImageView(
             kwargs['disable_sync_subtasks'] = False
 
         cache_filename = task.get(**kwargs)
-        cache_file = self.get_object().cache_partition.get_file(filename=cache_filename)
+        cache_file = obj.cache_partition.get_file(filename=cache_filename)
         with cache_file.open() as file_object:
-            response = HttpResponse(file_object.read(), content_type='image')
+            response = HttpResponse(content=file_object.read(), content_type='image')
             if '_hash' in request.GET:
                 patch_cache_control(
                     response=response,
