@@ -4,7 +4,7 @@ from django.db import models, migrations
 def operation_make_existing_documents_not_stubs(apps, schema_editor):
     Document = apps.get_model(app_label='documents', model_name='Document')
 
-    for document in Document.objects.using(schema_editor.connection.alias).all():
+    for document in Document.objects.using(alias=schema_editor.connection.alias).all():
         document.is_stub = False
         document.save()
 
