@@ -5,6 +5,7 @@ from django.contrib.auth import get_user_model
 from django.db import OperationalError
 
 from mayan.apps.lock_manager.exceptions import LockError
+from mayan.apps.converter.settings import setting_image_generation_max_retries
 from mayan.celery import app
 
 from .literals import (
@@ -56,7 +57,8 @@ def task_document_file_page_count_update(self, document_file_id):
 
 @app.task(
     bind=True,
-    default_retry_delay=setting_task_document_file_page_image_generate_retry_delay.value
+    default_retry_delay=setting_task_document_file_page_image_generate_retry_delay.value,
+    max_retries=setting_image_generation_max_retries.value
 )
 def task_document_file_page_image_generate(
     self, document_file_page_id, user_id=None, **kwargs
@@ -91,7 +93,7 @@ def task_document_file_page_image_generate(
     ignore_result=True
 )
 def task_document_file_upload(
-    self, document_id, shared_uploaded_file_id, user_id, action=None,
+    self, document_id, shared_uploaded_file_id, user_id=None, action=None,
     comment=None, filename=None
 ):
     Document = apps.get_model(
@@ -115,7 +117,8 @@ def task_document_file_upload(
     except OperationalError as exception:
         logger.warning(
             'Operational error during attempt to retrieve shared data for '
-            'new document file for:%s; %s. Retrying.', document, exception
+            'new document file for document ID: %s; %s. Retrying.', document_id,
+            exception
         )
         raise self.retry(exc=exception)
 
@@ -223,7 +226,8 @@ def task_document_version_export(
 
 @app.task(
     bind=True,
-    default_retry_delay=setting_task_document_version_page_image_generate_retry_delay.value
+    default_retry_delay=setting_task_document_version_page_image_generate_retry_delay.value,
+    max_retries=setting_image_generation_max_retries.value
 )
 def task_document_version_page_image_generate(
     self, document_version_page_id, user_id=None, **kwargs
