@@ -6,7 +6,8 @@ from mayan.apps.views.exceptions import ActionError
 from mayan.apps.views.generics import MultipleObjectConfirmActionView
 
 from ..icons import icon_favorite_document_list
-from ..models import Document, FavoriteDocument
+from ..models.document_models import Document
+from ..models.favorite_document_models import FavoriteDocument
 from ..permissions import permission_document_view
 from ..settings import setting_favorite_count
 
@@ -23,7 +24,7 @@ class FavoriteDocumentListView(DocumentListView):
         return FavoriteDocument.objects.get_for_user(user=self.request.user)
 
     def get_extra_context(self):
-        context = super(FavoriteDocumentListView, self).get_extra_context()
+        context = super().get_extra_context()
         context.update(
             {
                 'no_results_icon': icon_favorite_document_list,
@@ -39,9 +40,9 @@ class FavoriteDocumentListView(DocumentListView):
 
 
 class FavoriteAddView(MultipleObjectConfirmActionView):
-    model = Document
     object_permission = permission_document_view
     pk_url_kwarg = 'document_id'
+    source_queryset = Document.valid
     success_message = _(
         '%(count)d document added to favorites.'
     )
@@ -50,29 +51,32 @@ class FavoriteAddView(MultipleObjectConfirmActionView):
     )
 
     def get_extra_context(self):
-        queryset = self.object_list
-
-        return {
+        context = {
             'submit_label': _('Add'),
-            'submit_icon_class': icon_favorite_document_list,
+            'submit_icon': icon_favorite_document_list,
             'title': ungettext(
-                singular='Add the selected document to favorites',
-                plural='Add the selected documents to favorites',
-                number=queryset.count()
+                singular='Add the selected document to favorites?',
+                plural='Add the selected documents to favorites?',
+                number=self.object_list.count()
             )
         }
 
+        if self.object_list.count() == 1:
+            context['object'] = self.object_list.first()
+
+        return context
+
     def object_action(self, form, instance):
         FavoriteDocument.objects.add_for_user(
-            user=self.request.user, document=instance
+            document=instance, user=self.request.user
         )
 
 
 class FavoriteRemoveView(MultipleObjectConfirmActionView):
     error_message = _('Document "%(instance)s" is not in favorites.')
-    model = Document
     object_permission = permission_document_view
     pk_url_kwarg = 'document_id'
+    source_queryset = Document.valid
     success_message = _(
         '%(count)d document removed from favorites.'
     )
@@ -81,22 +85,25 @@ class FavoriteRemoveView(MultipleObjectConfirmActionView):
     )
 
     def get_extra_context(self):
-        queryset = self.object_list
-
-        return {
+        context = {
             'submit_label': _('Remove'),
-            'submit_icon_class': icon_favorite_document_list,
+            'submit_icon': icon_favorite_document_list,
             'title': ungettext(
-                singular='Remove the selected document from favorites',
-                plural='Remove the selected documents from favorites',
-                number=queryset.count()
+                singular='Remove the selected document from favorites?',
+                plural='Remove the selected documents from favorites?',
+                number=self.object_list.count()
             )
         }
 
+        if self.object_list.count() == 1:
+            context['object'] = self.object_list.first()
+
+        return context
+
     def object_action(self, form, instance):
         try:
             FavoriteDocument.objects.remove_for_user(
-                user=self.request.user, document=instance
+                document=instance, user=self.request.user
             )
         except FavoriteDocument.DoesNotExist:
             raise ActionError
