@@ -1,9 +1,9 @@
 from django.test import override_settings
 
-from mayan.apps.documents.models.document_models import Document
+from mayan.apps.documents.models.document_models import DocumentSearchResult
 from mayan.apps.documents.permissions import permission_document_view
 from mayan.apps.documents.search import document_search
-from mayan.apps.documents.tests.mixins import DocumentTestMixin
+from mayan.apps.documents.tests.mixins.document_mixins import DocumentTestMixin
 from mayan.apps.testing.tests.base import GenericViewTestCase
 from mayan.apps.storage.utils import fs_cleanup, mkdtemp
 
@@ -20,7 +20,7 @@ class AdvancedSearchViewTestCase(
     auto_upload_test_document = False
 
     def setUp(self):
-        super(AdvancedSearchViewTestCase, self).setUp()
+        super().setUp()
         self.test_document_count = 4
 
         # Upload many instances of the same test document
@@ -40,7 +40,7 @@ class AdvancedSearchViewTestCase(
         # Make sure all documents are returned by the search
         queryset = self.search_backend.search(
             search_model=document_search,
-            query_string={'label': test_document_label},
+            query={'label': test_document_label},
             user=self._test_case_user
         )
         self.assertEqual(queryset.count(), self.test_document_count)
@@ -113,7 +113,7 @@ class SearchToolsViewTestCase(
         self.old_value = setting_backend_arguments.value
         super().setUp()
         self.document_search_model = SearchModel.get_for_model(
-            instance=Document
+            instance=DocumentSearchResult
         )
         setting_backend_arguments.set(
             value={'index_path': mkdtemp()}
@@ -140,7 +140,7 @@ class SearchToolsViewTestCase(
 
         queryset = self.search_backend.search(
             search_model=self.document_search_model,
-            query_string={'q': self.test_document.label},
+            query={'q': self.test_document.label},
             user=self._test_case_user
         )
         self.assertEqual(queryset.count(), 0)
@@ -159,7 +159,7 @@ class SearchToolsViewTestCase(
 
         queryset = self.search_backend.search(
             search_model=self.document_search_model,
-            query_string={'q': self.test_document.label},
+            query={'q': self.test_document.label},
             user=self._test_case_user
         )
         self.assertNotEqual(queryset.count(), 0)
