@@ -20,7 +20,7 @@ class APIObjectEventListView(generics.ListAPIView):
     """
     get: Return a list of events for the specified object.
     """
-    ordering_fields = ('timestamp',)
+    ordering_fields = ('id', 'timestamp')
     serializer_class = EventSerializer
 
     def get_object(self):
@@ -117,7 +117,7 @@ class APIEventListView(generics.ListAPIView):
     get: Returns a list of all the available events.
     """
     mayan_view_permissions = {'GET': (permission_events_view,)}
-    ordering_fields = ('timestamp',)
+    ordering_fields = ('id', 'timestamp')
     queryset = Action.objects.all()
     serializer_class = EventSerializer
 
@@ -133,7 +133,7 @@ class APINotificationListView(generics.ListAPIView):
     """
     get: Return a list of notifications for the current user.
     """
-    ordering_fields = ('action__timestamp', 'read')
+    ordering_fields = ('action__timestamp', 'id', 'read')
     serializer_class = NotificationSerializer
 
     def get_queryset(self):
