@@ -1,4 +1,4 @@
-from django.db import migrations, models, transaction
+from django.db import migrations, models
 
 
 def operation_remove_duplicates(apps, schema_editor):
@@ -11,12 +11,9 @@ def operation_remove_duplicates(apps, schema_editor):
 
     driver = StoredDriver.objects.first()
     if driver:
-        with transaction.atomic():
-            for driver_entry in DocumentVersionDriverEntry.objects.using(schema_editor.connection.alias).all():
-                driver_entry.driver = driver
-                driver_entry.save()
+        DocumentVersionDriverEntry.objects.using(alias=schema_editor.connection.alias).update(driver=driver)
 
-            StoredDriver.objects.exclude(pk=driver.id).delete()
+        StoredDriver.objects.exclude(pk=driver.id).delete()
 
 
 class Migration(migrations.Migration):
@@ -44,5 +41,7 @@ class Migration(migrations.Migration):
                 verbose_name='Internal name'
             ),
         ),
-
+    ]
+    run_before = [
+        ('documents', '0057_auto_20200916_1057'),
     ]
