@@ -165,7 +165,7 @@ class APISmartLinkConditionListView(
         'GET': (permission_smart_link_view,),
         'POST': (permission_smart_link_edit,)
     }
-    ordering_fields = ('enabled',)
+    ordering_fields = ('enabled', 'id')
     serializer_class = SmartLinkConditionSerializer
 
     def get_instance_extra_data(self):
@@ -264,7 +264,7 @@ class APISmartLinkDetailView(generics.RetrieveUpdateDestroyAPIView):
         'PATCH': (permission_smart_link_edit,),
         'PUT': (permission_smart_link_edit,)
     }
-    ordering_fields = ('dynamic_label', 'enabled', 'label')
+    ordering_fields = ('dynamic_label', 'enabled', 'id', 'label')
     queryset = SmartLink.objects.all()
     serializer_class = SmartLinkSerializer
 
