@@ -1,22 +1,20 @@
 # -*- coding: utf-8 -*-
 
+DOCUMENT_METADATA_ADD_ACTION_CLASS_PATH = 'mayan.apps.metadata.workflow_actions.DocumentMetadataAddAction'
+DOCUMENT_METADATA_EDIT_ACTION_CLASS_PATH = 'mayan.apps.metadata.workflow_actions.DocumentMetadataEditAction'
+DOCUMENT_METADATA_REMOVE_ACTION_CLASS_PATH = 'mayan.apps.metadata.workflow_actions.DocumentMetadataRemoveAction'
 TEST_CORRECT_LOOKUP_VALUE = '1'
 TEST_DATE_PARSER = 'mayan.apps.metadata.parsers.DateParser'
 TEST_DATE_VALIDATOR = 'mayan.apps.metadata.validators.DateValidator'
-TEST_DOCUMENT_METADATA_VALUE_2 = 'test document metadata value 2'
 TEST_DEFAULT_VALUE = 'test'
 TEST_INCORRECT_LOOKUP_VALUE = '0'
 TEST_INVALID_DATE = '___________'
 TEST_LOOKUP_TEMPLATE = '1,2,3'
 TEST_METADATA_TYPE_DEFAULT_VALUE = 'default value'
-TEST_METADATA_TYPES_FIXTURES = [
-    {'name': 'test_metadata_type_1', 'label': 'test metadata type 1'},
-    {'name': 'test_metadata_type_2', 'label': 'test metadata type 2'},
-]
-TEST_METADATA_TYPE_LABEL_2 = 'test metadata type label 2'
+TEST_METADATA_TYPE_LABEL = 'test metadata type label'
+TEST_METADATA_TYPE_NAME = 'test_metadata_type_name'
 TEST_METADATA_TYPE_LABEL_EDITED = 'test metadata type label edited'
-TEST_METADATA_TYPE_NAME_2 = 'test metadata type name 2'
-TEST_METADATA_TYPE_NAME_EDITED = 'test metadata type name edited'
+TEST_METADATA_TYPE_NAME_EDITED = 'test_metadata_type_name_edited'
 TEST_METADATA_VALUE = 'test value'
 TEST_METADATA_VALUE_EDITED = 'test value edited'
 TEST_METADATA_VALUE_UNICODE = 'español'
