@@ -4,7 +4,7 @@ from django.core.exceptions import ValidationError
 
 from mayan.apps.documents.models import DocumentType
 from mayan.apps.documents.tests.literals import TEST_DOCUMENT_TYPE_2_LABEL
-from mayan.apps.documents.tests.mixins import DocumentTestMixin
+from mayan.apps.documents.tests.mixins.document_mixins import DocumentTestMixin
 from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..models import DocumentMetadata
@@ -17,9 +17,15 @@ from .literals import (
 from .mixins import MetadataTypeTestMixin
 
 
-class MetadataTypeTestCase(DocumentTestMixin, MetadataTypeTestMixin, BaseTestCase):
+class MetadataTypeTestCase(
+    DocumentTestMixin, MetadataTypeTestMixin, BaseTestCase
+):
+    auto_upload_test_document = False
+
     def setUp(self):
-        super(MetadataTypeTestCase, self).setUp()
+        super().setUp()
+
+        self._create_test_document_stub()
         self._create_test_metadata_type()
         self.test_document_type.metadata.create(
             metadata_type=self.test_metadata_type
@@ -209,7 +215,7 @@ class MetadataTypeTestCase(DocumentTestMixin, MetadataTypeTestMixin, BaseTestCas
             metadata_type=self.test_metadata_type, required=True
         )
 
-        self.test_document.set_document_type(document_type=self.test_document_type_2)
+        self.test_document.document_type_change(document_type=self.test_document_type_2)
 
         self.assertEqual(self.test_document.metadata.count(), 1)
         self.assertEqual(
@@ -235,7 +241,7 @@ class MetadataTypeTestCase(DocumentTestMixin, MetadataTypeTestMixin, BaseTestCas
 
         self.test_document_type_2.metadata.create(metadata_type=self.test_metadata_type)
 
-        self.test_document.set_document_type(document_type=self.test_document_type_2)
+        self.test_document.document_type_change(document_type=self.test_document_type_2)
 
         self.assertEqual(self.test_document.metadata.count(), 1)
         self.assertEqual(
@@ -262,7 +268,7 @@ class MetadataTypeTestCase(DocumentTestMixin, MetadataTypeTestMixin, BaseTestCas
             label=TEST_DOCUMENT_TYPE_2_LABEL
         )
 
-        self.test_document.set_document_type(document_type=self.test_document_type_2)
+        self.test_document.document_type_change(document_type=self.test_document_type_2)
 
         self.assertEqual(self.test_document.metadata.count(), 0)
 
@@ -287,7 +293,7 @@ class MetadataTypeTestCase(DocumentTestMixin, MetadataTypeTestMixin, BaseTestCas
             metadata_type=self.test_metadata_type, required=True
         )
 
-        self.test_document.set_document_type(document_type=self.test_document_type_2)
+        self.test_document.document_type_change(document_type=self.test_document_type_2)
 
         self.assertEqual(self.test_document.metadata.count(), 1)
         self.assertEqual(
