@@ -1,8 +1,6 @@
-from mayan.apps.document_states.permissions import permission_workflow_edit
-from mayan.apps.document_states.tests.base import ActionTestCase
-from mayan.apps.document_states.tests.mixins import (
-    WorkflowTestMixin, WorkflowStateActionViewTestMixin
-)
+from mayan.apps.document_states.permissions import permission_workflow_template_edit
+from mayan.apps.document_states.tests.mixins.workflow_template_mixins import WorkflowTemplateTestMixin
+from mayan.apps.document_states.tests.mixins.workflow_template_state_mixins import WorkflowTemplateStateActionViewTestMixin
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
 
 from ..models import MetadataType
@@ -15,19 +13,22 @@ from ..permissions import (
     permission_document_metadata_remove
 )
 
-from .literals import TEST_METADATA_VALUE
+from .literals import (
+    DOCUMENT_METADATA_ADD_ACTION_CLASS_PATH,
+    DOCUMENT_METADATA_EDIT_ACTION_CLASS_PATH,
+    DOCUMENT_METADATA_REMOVE_ACTION_CLASS_PATH, TEST_METADATA_VALUE
+)
 from .mixins import DocumentMetadataMixin, MetadataTypeTestMixin
 
-DOCUMENT_METADATA_ADD_ACTION_CLASS_PATH = 'mayan.apps.metadata.workflow_actions.DocumentMetadataAddAction'
-DOCUMENT_METADATA_EDIT_ACTION_CLASS_PATH = 'mayan.apps.metadata.workflow_actions.DocumentMetadataEditAction'
-DOCUMENT_METADATA_REMOVE_ACTION_CLASS_PATH = 'mayan.apps.metadata.workflow_actions.DocumentMetadataRemoveAction'
-
 
 class DocumentMetadataActionTestCase(
-    DocumentMetadataMixin, MetadataTypeTestMixin, ActionTestCase
+    DocumentMetadataMixin, MetadataTypeTestMixin
 ):
+    auto_upload_test_document = False
+
     def setUp(self):
         super().setUp()
+        self._create_test_document_stub()
         self._create_test_metadata_type()
         self.test_document_type.metadata.create(
             metadata_type=self.test_metadata_type
@@ -89,24 +90,27 @@ class DocumentMetadataActionTestCase(
 
 class DocumentMetadataActionViewTestCase(
     DocumentMetadataMixin, MetadataTypeTestMixin,
-    WorkflowStateActionViewTestMixin, WorkflowTestMixin,
+    WorkflowTemplateStateActionViewTestMixin, WorkflowTemplateTestMixin,
     GenericDocumentViewTestCase
 ):
+    auto_upload_test_document = False
+
     def setUp(self):
         super().setUp()
-        self._create_test_workflow()
-        self._create_test_workflow_state()
+        self._create_test_document_stub()
+        self._create_test_workflow_template()
+        self._create_test_workflow_template_state()
         self._create_test_metadata_type()
         self.test_document_type.metadata.create(
             metadata_type=self.test_metadata_type
         )
-        self.test_workflow.document_types.add(
+        self.test_workflow_template.document_types.add(
             self.test_document_type
         )
 
     def test_document_metadata_add_action_create_view(self):
         self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_edit
+            obj=self.test_workflow_template, permission=permission_workflow_template_edit
         )
         self.grant_access(
             obj=self.test_metadata_type,
@@ -124,7 +128,7 @@ class DocumentMetadataActionViewTestCase(
         self._create_test_document_metadata()
 
         self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_edit
+            obj=self.test_workflow_template, permission=permission_workflow_template_edit
         )
         self.grant_access(
             obj=self.test_metadata_type,
@@ -143,7 +147,7 @@ class DocumentMetadataActionViewTestCase(
         self._create_test_document_metadata()
 
         self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_edit
+            obj=self.test_workflow_template, permission=permission_workflow_template_edit
         )
         self.grant_access(
             obj=self.test_metadata_type,
