@@ -12,7 +12,9 @@ from django.db.models import (
 )
 from django.db.models.functions import Concat
 
-from mayan.apps.document_indexing.models import Index, IndexInstanceNode
+from mayan.apps.document_indexing.models import (
+    IndexInstanceNode, IndexTemplate
+)
 from mayan.apps.documents.models import Document
 
 from .literals import (
@@ -136,7 +138,7 @@ class IndexFilesystem(LoggingMixIn, Operations):
 
         logger.debug('parts: %s', parts)
 
-        node = self.index.instance_root
+        node = self.index_template.instance_root
 
         if len(parts) > 1 and parts[1] != '':
             path_cache = cache.get_path(path=path)
@@ -156,7 +158,7 @@ class IndexFilesystem(LoggingMixIn, Operations):
                     else:
                         return Document.valid.get(pk=document_pk)
 
-            for count, part in enumerate(parts[1:]):
+            for count, part in enumerate(iterable=parts[1:]):
                 try:
                     node = IndexFilesystem._clean_queryset(
                         queryset=node.get_children(),
@@ -211,8 +213,8 @@ class IndexFilesystem(LoggingMixIn, Operations):
         self.file_descriptors = {}
 
         try:
-            self.index = Index.objects.get(slug=index_slug)
-        except Index.DoesNotExist:
+            self.index_template = IndexTemplate.objects.get(slug=index_slug)
+        except IndexTemplate.DoesNotExist:
             print('Unknown index slug: {}.'.format(index_slug))
             exit(1)
 
@@ -245,13 +247,13 @@ class IndexFilesystem(LoggingMixIn, Operations):
             function_result = {
                 'st_mode': (S_IFREG | FILE_MODE),
                 'st_ctime': (
-                    result.date_added.replace(tzinfo=None) - result.date_added.utcoffset() - datetime.datetime(1970, 1, 1)
+                    result.datetime_created.replace(tzinfo=None) - result.datetime_created.utcoffset() - datetime.datetime(1970, 1, 1)
                 ).total_seconds(),
                 'st_mtime': (
-                    result.latest_version.timestamp.replace(tzinfo=None) - result.latest_version.timestamp.utcoffset() - datetime.datetime(1970, 1, 1)
+                    result.file_latest.timestamp.replace(tzinfo=None) - result.file_latest.timestamp.utcoffset() - datetime.datetime(1970, 1, 1)
                 ).total_seconds(),
                 'st_atime': now,
-                'st_size': result.size or 0,
+                'st_size': result.file_latest.size or 0,
                 'st_nlink': 1
             }
 
@@ -263,7 +265,7 @@ class IndexFilesystem(LoggingMixIn, Operations):
 
         if isinstance(result, Document):
             next_file_descriptor = self._get_next_file_descriptor()
-            self.file_descriptors[next_file_descriptor] = result.open()
+            self.file_descriptors[next_file_descriptor] = result.file_latest.open()
             return next_file_descriptor
         else:
             raise FuseOSError(ENOENT)
