@@ -1,17 +1,13 @@
 from django.contrib import admin
 
 from .models import (
-    DocumentPageOCRContent, DocumentTypeSettings, DocumentVersionOCRError
+    DocumentTypeOCRSettings, DocumentVersionOCRError,
+    DocumentVersionPageOCRContent
 )
 
 
-@admin.register(DocumentPageOCRContent)
-class DocumentPageOCRContentAdmin(admin.ModelAdmin):
-    list_display = ('document_page',)
-
-
-@admin.register(DocumentTypeSettings)
-class DocumentTypeSettingsAdmin(admin.ModelAdmin):
+@admin.register(DocumentTypeOCRSettings)
+class DocumentTypeOCRSettingsAdmin(admin.ModelAdmin):
     list_display = ('document_type', 'auto_ocr')
 
 
@@ -19,3 +15,8 @@ class DocumentTypeSettingsAdmin(admin.ModelAdmin):
 class DocumentVersionOCRErrorAdmin(admin.ModelAdmin):
     list_display = ('document_version', 'datetime_submitted')
     readonly_fields = ('document_version', 'datetime_submitted', 'result')
+
+
+@admin.register(DocumentVersionPageOCRContent)
+class DocumentVersionPageOCRContentAdmin(admin.ModelAdmin):
+    list_display = ('document_version_page',)
