@@ -15,19 +15,22 @@ from mayan.apps.events.classes import ModelEventType
 from mayan.apps.navigation.classes import SourceColumn
 
 from .events import (
-    event_ocr_document_version_content_deleted, event_ocr_document_version_finish,
-    event_ocr_document_version_submit
+    event_ocr_document_version_content_deleted,
+    event_ocr_document_version_finished, event_ocr_document_version_submitted
 )
 from .handlers import (
     handler_index_document_version, handler_initialize_new_ocr_settings,
     handler_ocr_document_version,
 )
 from .links import (
-    link_document_version_page_ocr_content_view, link_document_version_ocr_content_view,
+    link_document_version_page_ocr_content_detail_view,
+    link_document_version_ocr_content_view,
     link_document_version_ocr_content_delete,
-    link_document_version_multiple_ocr_content_delete, link_document_version_ocr_download,
+    link_document_version_multiple_ocr_content_delete,
+    link_document_version_ocr_download,
     link_document_version_ocr_errors_list, link_document_version_ocr_submit,
-    link_document_version_multiple_ocr_submit, link_document_type_ocr_settings,
+    link_document_version_multiple_ocr_submit,
+    link_document_type_ocr_settings,
     link_document_type_submit, link_entry_list
 )
 from .methods import (
@@ -90,8 +93,8 @@ class OCRApp(MayanAppConfig):
         ModelEventType.register(
             model=Document, event_types=(
                 event_ocr_document_version_content_deleted,
-                event_ocr_document_version_finish,
-                event_ocr_document_version_submit
+                event_ocr_document_version_finished,
+                event_ocr_document_version_submitted
             )
         )
 
@@ -112,7 +115,8 @@ class OCRApp(MayanAppConfig):
 
         ModelPermission.register(
             model=Document, permissions=(
-                permission_document_version_ocr, permission_document_version_ocr_content_view
+                permission_document_version_ocr,
+                permission_document_version_ocr_content_view
             )
         )
         ModelPermission.register(
@@ -125,8 +129,9 @@ class OCRApp(MayanAppConfig):
         )
 
         SourceColumn(
-            attribute='document_version__document', is_attribute_absolute_url=True,
-            is_identifier=True, is_sortable=True, source=DocumentVersionOCRError
+            attribute='document_version__document',
+            is_attribute_absolute_url=True, is_identifier=True,
+            is_sortable=True, source=DocumentVersionOCRError
         )
         SourceColumn(
             attribute='datetime_submitted', is_sortable=True,
@@ -138,10 +143,12 @@ class OCRApp(MayanAppConfig):
         )
 
         menu_list_facet.bind_links(
-            links=(link_document_version_ocr_content_view,), sources=(DocumentVersion,)
+            links=(link_document_version_ocr_content_view,),
+            sources=(DocumentVersion,)
         )
         menu_list_facet.bind_links(
-            links=(link_document_version_page_ocr_content_view,), sources=(DocumentVersionPage,)
+            links=(link_document_version_page_ocr_content_detail_view,),
+            sources=(DocumentVersionPage,)
         )
         menu_list_facet.bind_links(
             links=(link_document_type_ocr_settings,), sources=(DocumentType,)
@@ -156,7 +163,8 @@ class OCRApp(MayanAppConfig):
             links=(
                 link_document_version_ocr_content_delete,
                 link_document_version_ocr_errors_list,
-                link_document_version_ocr_download, link_document_version_ocr_submit
+                link_document_version_ocr_download,
+                link_document_version_ocr_submit
             ),
             sources=(
                 'ocr:document_version_ocr_content_view_delete',
