@@ -6,10 +6,10 @@ from django.utils.translation import ugettext_lazy as _, ugettext
 
 from mayan.apps.views.widgets import TextAreaDiv
 
-from .models import DocumentPageOCRContent
+from .models import DocumentVersionPageOCRContent
 
 
-class DocumentPageOCRContentForm(forms.Form):
+class DocumentVersionPageOCRContentForm(forms.Form):
     contents = forms.CharField(
         label=_('Contents'),
         widget=TextAreaDiv(
@@ -22,21 +22,23 @@ class DocumentPageOCRContentForm(forms.Form):
 
     def __init__(self, *args, **kwargs):
         page = kwargs.pop('instance', None)
-        super(DocumentPageOCRContentForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         content = ''
         self.fields['contents'].initial = ''
 
         try:
             page_content = page.ocr_content.content
-        except DocumentPageOCRContent.DoesNotExist:
-            pass
+        except DocumentVersionPageOCRContent.DoesNotExist:
+            """
+            Not critical, just ignore and proceed to next page.
+            """
         else:
-            content = conditional_escape(force_text(page_content))
+            content = conditional_escape(force_text(s=page_content))
 
         self.fields['contents'].initial = mark_safe(content)
 
 
-class DocumentOCRContentForm(forms.Form):
+class DocumentVersionOCRContentForm(forms.Form):
     """
     Form that concatenates all of a document pages' text content into a
     single textarea widget
@@ -53,7 +55,7 @@ class DocumentOCRContentForm(forms.Form):
 
     def __init__(self, *args, **kwargs):
         self.document = kwargs.pop('instance', None)
-        super(DocumentOCRContentForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         content = []
         self.fields['contents'].initial = ''
         try:
@@ -64,10 +66,12 @@ class DocumentOCRContentForm(forms.Form):
         for page in document_pages:
             try:
                 page_content = page.ocr_content.content
-            except DocumentPageOCRContent.DoesNotExist:
-                pass
+            except DocumentVersionPageOCRContent.DoesNotExist:
+                """
+                Not critical, just ignore and proceed to next page.
+                """
             else:
-                content.append(conditional_escape(force_text(page_content)))
+                content.append(conditional_escape(force_text(s=page_content)))
                 content.append(
                     '\n\n\n<hr/><div class="document-page-content-divider">- %s -</div><hr/>\n\n\n' % (
                         ugettext(
