@@ -8,8 +8,7 @@ from django.utils.encoding import force_text
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.common.class_mixins import AppsModuleLoaderMixin
-
-from .exceptions import InvalidNamespace
+from mayan.apps.common.collections import ClassCollection
 
 logger = logging.getLogger(name=__name__)
 
@@ -26,7 +25,7 @@ class PermissionNamespace:
         try:
             return cls._registry[name]
         except KeyError:
-            raise InvalidNamespace(
+            raise KeyError(
                 'Invalid namespace name. This is probably an obsolete '
                 'permission namespace, execute the management command '
                 '"purgepermissions" and try again.'
@@ -39,7 +38,7 @@ class PermissionNamespace:
         self.__class__._registry[name] = self
 
     def __str__(self):
-        return force_text(self.label)
+        return force_text(s=self.label)
 
     def add_permission(self, name, label):
         permission = Permission(namespace=self, name=name, label=label)
@@ -56,11 +55,11 @@ class Permission(AppsModuleLoaderMixin):
     @classmethod
     def all(cls, as_choices=False):
         if as_choices:
-            results = []
+            results = PermissionCollection()
 
             for namespace, permissions in itertools.groupby(cls.all(), lambda entry: entry.namespace):
                 permission_options = [
-                    (force_text(permission.pk), permission) for permission in permissions
+                    (force_text(s=permission.pk), permission) for permission in permissions
                 ]
                 results.append(
                     (namespace, permission_options)
@@ -69,8 +68,10 @@ class Permission(AppsModuleLoaderMixin):
             return results
         else:
             # Return sorted permissions by namespace.name
-            return sorted(
-                cls._permissions.values(), key=lambda x: x.namespace.name
+            return PermissionCollection(
+                sorted(
+                    cls._permissions.values(), key=lambda x: x.namespace.name
+                )
             )
 
     @classmethod
@@ -94,6 +95,7 @@ class Permission(AppsModuleLoaderMixin):
     @classmethod
     def load_modules(cls):
         super().load_modules()
+
         # Invalidate cache always. This is for tests that build a new memory
         # only database and cause all cache references built in the .ready()
         # method to be invalid.
@@ -117,7 +119,7 @@ class Permission(AppsModuleLoaderMixin):
         return self.pk
 
     def __str__(self):
-        return force_text(self.label)
+        return force_text(s=self.label)
 
     def get_pk(self):
         return '%s.%s' % (self.namespace.name, self.name)
@@ -145,3 +147,7 @@ class Permission(AppsModuleLoaderMixin):
                 stored permissions during the initial creation of the
                 database. Can be safely ignore under that situation.
                 """
+
+
+class PermissionCollection(ClassCollection):
+    klass = Permission
