@@ -279,7 +279,7 @@ class Setting:
 
     def __init__(
         self, namespace, global_name, default, help_text=None, is_path=False,
-        post_edit_function=None
+        post_edit_function=None, validation_function=None
     ):
         self.global_name = global_name
         self.default = default
@@ -288,6 +288,7 @@ class Setting:
         self.namespace = namespace
         self.environment_variable = False
         self.post_edit_function = post_edit_function
+        self.validation_function = validation_function
         namespace._settings.append(self)
         self.__class__._registry[global_name] = self
 
@@ -329,6 +330,11 @@ class Setting:
                 # Found in the config file, try to migrate the value
                 self.migrate()
 
+        if self.validation_function:
+            self.raw_value = self.validation_function(
+                setting=self, raw_value=self.raw_value
+            )
+
         self.yaml = Setting.serialize_value(self.raw_value)
         self.loaded = True
 
@@ -361,6 +367,12 @@ class Setting:
         self.value = Setting.serialize_value(value=value)
         self.loaded = True
 
+    def validate(self, raw_value):
+        if self.validation_function:
+            return self.validation_function(
+                setting=self, raw_value=raw_value
+            )
+
     @property
     def value(self):
         if not self.loaded:
