@@ -14,7 +14,7 @@ class SettingForm(forms.Form):
     )
 
     def __init__(self, *args, **kwargs):
-        super(SettingForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.setting = self.initial['setting']
         self.fields['value'].help_text = self.setting.help_text
         self.fields['value'].initial = self.setting.serialized_value
@@ -28,3 +28,5 @@ class SettingForm(forms.Form):
                     '"%s" not a valid entry.'
                 ) % self.cleaned_data['value']
             )
+        else:
+            self.setting.validate(raw_value=self.cleaned_data['value'])
