@@ -7,53 +7,10 @@ from ..compressed_files import Archive, MsgArchive, TarArchive, ZipArchive
 from .literals import (
     TEST_ARCHIVE_MSG_STRANGE_DATE_PATH, TEST_ARCHIVE_ZIP_CP437_MEMBER_PATH,
     TEST_ARCHIVE_ZIP_SPECIAL_CHARACTERS_FILENAME_MEMBER_PATH,
-    TEST_COMPRESSED_FILE_CONTENTS, TEST_FILE_CONTENTS_1, TEST_FILE3_PATH,
-    TEST_FILENAME1, TEST_FILENAME3, TEST_TAR_BZ2_FILE_PATH,
-    TEST_TAR_FILE_PATH, TEST_TAR_GZ_FILE_PATH, TEST_ZIP_FILE_PATH
+    TEST_TAR_BZ2_FILE_PATH, TEST_TAR_FILE_PATH, TEST_TAR_GZ_FILE_PATH,
+    TEST_ZIP_FILE_PATH
 )
-
-
-class ArchiveClassTestCaseMixin:
-    archive_path = None
-    cls = None
-    filename = TEST_FILENAME3
-    file_path = TEST_FILE3_PATH
-    members_list = TEST_COMPRESSED_FILE_CONTENTS
-    member_name = TEST_FILENAME1
-    member_contents = TEST_FILE_CONTENTS_1
-
-    def test_add_file(self):
-        archive = self.cls()
-        archive.create()
-        with open(file=self.file_path, mode='rb') as file_object:
-            archive.add_file(file_object=file_object, filename=self.filename)
-            self.assertTrue(archive.members(), [self.filename])
-
-    def test_open(self):
-        with open(file=self.archive_path, mode='rb') as file_object:
-            archive = Archive.open(file_object=file_object)
-            self.assertTrue(isinstance(archive, self.cls))
-
-    def test_members(self):
-        with open(file=self.archive_path, mode='rb') as file_object:
-            archive = Archive.open(file_object=file_object)
-            self.assertEqual(archive.members(), self.members_list)
-
-    def test_member_contents(self):
-        with open(file=self.archive_path, mode='rb') as file_object:
-            archive = Archive.open(file_object=file_object)
-            self.assertEqual(
-                archive.member_contents(filename=self.member_name),
-                self.member_contents
-            )
-
-    def test_open_member(self):
-        with open(file=self.archive_path, mode='rb') as file_object:
-            archive = Archive.open(file_object=file_object)
-            file_object = archive.open_member(filename=self.member_name)
-            self.assertEqual(
-                file_object.read(), self.member_contents
-            )
+from .mixins import ArchiveClassTestCaseMixin
 
 
 class MsgArchiveClassTestCase(ArchiveClassTestCaseMixin, BaseTestCase):
@@ -90,7 +47,7 @@ Zealand. '''.replace('\n', '\r\n')
                 archive.member_contents(
                     filename=self.member_name
                 ).startswith(
-                    force_bytes(self.member_contents_partial)
+                    force_bytes(s=self.member_contents_partial)
                 )
             )
 
@@ -100,7 +57,7 @@ Zealand. '''.replace('\n', '\r\n')
             file_object = archive.open_member(filename=self.member_name)
             self.assertTrue(
                 file_object.read().startswith(
-                    force_bytes(self.member_contents_partial)
+                    force_bytes(s=self.member_contents_partial)
                 )
             )
 
