@@ -1,6 +1,6 @@
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.common.forms import FilteredSelectionForm
+from mayan.apps.views.forms import FilteredSelectionForm
 
 from .widgets import TagFormWidget
 
