@@ -8,7 +8,7 @@ from .mixins import DocumentTemplateSandboxViewTestMixin
 class DocumentTemplateSandboxViewTestCase(
     DocumentTemplateSandboxViewTestMixin, GenericDocumentViewTestCase
 ):
-    def test_document_template_sanbox_get_view_no_permissions(self):
+    def test_document_template_sanbox_get_view_no_permission(self):
         response = self._request_document_template_sandbox_get_view()
         self.assertEqual(response.status_code, 404)
 
@@ -20,7 +20,7 @@ class DocumentTemplateSandboxViewTestCase(
         response = self._request_document_template_sandbox_get_view()
         self.assertEqual(response.status_code, 200)
 
-    def test_document_template_sanbox_post_view_no_permissions(self):
+    def test_document_template_sanbox_post_view_no_permission(self):
         response = self._request_document_template_sandbox_post_view()
         self.assertEqual(response.status_code, 404)
 
