@@ -10,7 +10,7 @@ from .permissions import permission_group_view, permission_user_view
 
 
 class DashboardWidgetUserTotal(DashboardWidgetNumeric):
-    icon_class = icon_user_list
+    icon = icon_user_list
     label = _('Total users')
     link = reverse_lazy(viewname='user_management:user_list')
 
@@ -22,11 +22,11 @@ class DashboardWidgetUserTotal(DashboardWidgetNumeric):
             permission=permission_user_view, user=request.user,
             queryset=get_user_model().objects.all()
         ).count()
-        return super(DashboardWidgetUserTotal, self).render(request)
+        return super().render(request)
 
 
 class DashboardWidgetGroupTotal(DashboardWidgetNumeric):
-    icon_class = icon_group_list
+    icon = icon_group_list
     label = _('Total groups')
     link = reverse_lazy(viewname='user_management:group_list')
 
@@ -41,4 +41,4 @@ class DashboardWidgetGroupTotal(DashboardWidgetNumeric):
             permission=permission_group_view, user=request.user,
             queryset=Group.objects.all()
         ).count()
-        return super(DashboardWidgetGroupTotal, self).render(request)
+        return super().render(request)
