@@ -1,5 +1,5 @@
 from mayan.apps.common.tests.mixins import ObjectCopyTestMixin
-from mayan.apps.documents.tests.mixins import DocumentTestMixin
+from mayan.apps.documents.tests.mixins.document_mixins import DocumentTestMixin
 from mayan.apps.testing.tests.base import BaseTestCase
 
 from .mixins import WebLinkTestMixin
