@@ -1,6 +1,5 @@
 import logging
 
-from django.db import transaction
 from django.shortcuts import get_object_or_404
 from django.template import RequestContext
 from django.urls import reverse_lazy
@@ -8,14 +7,13 @@ from django.utils.translation import ugettext_lazy as _
 from django.views.generic import RedirectView
 
 from mayan.apps.acls.models import AccessControlList
-from mayan.apps.documents.events import event_document_type_edited
 from mayan.apps.documents.models import Document, DocumentType
 from mayan.apps.documents.permissions import permission_document_type_edit
 from mayan.apps.views.generics import (
     AddRemoveView, SingleObjectCreateView, SingleObjectDeleteView,
     SingleObjectEditView, SingleObjectListView
 )
-from mayan.apps.views.mixins import ExternalObjectMixin
+from mayan.apps.views.mixins import ExternalObjectViewMixin
 
 from .events import event_web_link_edited
 from .forms import WebLinkForm
@@ -32,8 +30,6 @@ logger = logging.getLogger(name=__name__)
 
 
 class DocumentTypeWebLinksView(AddRemoveView):
-    main_object_method_add = 'web_link_add'
-    main_object_method_remove = 'web_link_remove'
     main_object_permission = permission_document_type_edit
     main_object_model = DocumentType
     main_object_pk_url_kwarg = 'document_type_id'
@@ -43,30 +39,22 @@ class DocumentTypeWebLinksView(AddRemoveView):
     list_added_title = _('Web links enabled')
     related_field = 'web_links'
 
-    def action_add(self, queryset, _user):
-        with transaction.atomic():
-            event_document_type_edited.commit(
-                actor=_user, target=self.main_object
+    def action_add(self, queryset, _event_actor):
+        for obj in queryset:
+            self.main_object.web_links.add(obj)
+            event_web_link_edited.commit(
+                actor=_event_actor, action_object=self.main_object, target=obj
             )
-            for obj in queryset:
-                self.main_object.web_links.add(obj)
-                event_web_link_edited.commit(
-                    actor=_user, action_object=self.main_object, target=obj
-                )
 
-    def action_remove(self, queryset, _user):
-        with transaction.atomic():
-            event_document_type_edited.commit(
-                actor=_user, target=self.main_object
+    def action_remove(self, queryset, _event_actor):
+        for obj in queryset:
+            self.main_object.web_links.remove(obj)
+            event_web_link_edited.commit(
+                actor=_event_actor, action_object=self.main_object, target=obj
             )
-            for obj in queryset:
-                self.main_object.web_links.remove(obj)
-                event_web_link_edited.commit(
-                    actor=_user, action_object=self.main_object, target=obj
-                )
 
     def get_actions_extra_kwargs(self):
-        return {'_user': self.request.user}
+        return {'_event_actor': self.request.user}
 
     def get_extra_context(self):
         return {
@@ -77,10 +65,10 @@ class DocumentTypeWebLinksView(AddRemoveView):
         }
 
 
-class ResolvedWebLinkView(ExternalObjectMixin, RedirectView):
-    external_object_class = Document
+class ResolvedWebLinkView(ExternalObjectViewMixin, RedirectView):
     external_object_pk_url_kwarg = 'document_id'
     external_object_permission = permission_web_link_instance_view
+    external_object_queryset = Document.valid
 
     def get_redirect_url(self, *args, **kwargs):
         return self.get_web_link().get_redirect(
@@ -102,9 +90,36 @@ class ResolvedWebLinkView(ExternalObjectMixin, RedirectView):
         )
 
 
+class WebLinkCreateView(SingleObjectCreateView):
+    extra_context = {'title': _('Create new web link')}
+    form_class = WebLinkForm
+    post_action_redirect = reverse_lazy(
+        viewname='web_links:web_link_list'
+    )
+    view_permission = permission_web_link_create
+
+    def get_instance_extra_data(self):
+        return {'_event_actor': self.request.user}
+
+
+class WebLinkDeleteView(SingleObjectDeleteView):
+    model = WebLink
+    object_permission = permission_web_link_delete
+    pk_url_kwarg = 'web_link_id'
+    post_action_redirect = reverse_lazy(
+        viewname='web_links:web_link_list'
+    )
+
+    def get_extra_context(self):
+        return {
+            'object': self.object,
+            'title': _('Delete web link: %s') % self.object
+        }
+
+
 class WebLinkDocumentTypesView(AddRemoveView):
-    main_object_method_add = 'document_types_add'
-    main_object_method_remove = 'document_types_remove'
+    main_object_method_add_name = 'document_types_add'
+    main_object_method_remove_name = 'document_types_remove'
     main_object_permission = permission_web_link_edit
     main_object_model = WebLink
     main_object_pk_url_kwarg = 'web_link_id'
@@ -115,7 +130,7 @@ class WebLinkDocumentTypesView(AddRemoveView):
     related_field = 'document_types'
 
     def get_actions_extra_kwargs(self):
-        return {'_user': self.request.user}
+        return {'_event_actor': self.request.user}
 
     def get_extra_context(self):
         return {
@@ -126,6 +141,25 @@ class WebLinkDocumentTypesView(AddRemoveView):
         }
 
 
+class WebLinkEditView(SingleObjectEditView):
+    form_class = WebLinkForm
+    model = WebLink
+    object_permission = permission_web_link_edit
+    pk_url_kwarg = 'web_link_id'
+    post_action_redirect = reverse_lazy(
+        viewname='web_links:web_link_list'
+    )
+
+    def get_extra_context(self):
+        return {
+            'object': self.object,
+            'title': _('Edit web link: %s') % self.object
+        }
+
+    def get_instance_extra_data(self):
+        return {'_event_actor': self.request.user}
+
+
 class WebLinkListView(SingleObjectListView):
     object_permission = permission_web_link_view
 
@@ -155,10 +189,10 @@ class WebLinkListView(SingleObjectListView):
         return WebLink.objects.all()
 
 
-class DocumentWebLinkListView(ExternalObjectMixin, WebLinkListView):
-    external_object_class = Document
+class DocumentWebLinkListView(ExternalObjectViewMixin, WebLinkListView):
     external_object_permission = permission_web_link_instance_view
     external_object_pk_url_kwarg = 'document_id'
+    external_object_queryset = Document.valid
     object_permission = permission_web_link_instance_view
 
     def get_extra_context(self):
@@ -183,49 +217,3 @@ class DocumentWebLinkListView(ExternalObjectMixin, WebLinkListView):
         return ResolvedWebLink.objects.get_for(
             document=self.external_object, user=self.request.user
         )
-
-
-class WebLinkCreateView(SingleObjectCreateView):
-    extra_context = {'title': _('Create new web link')}
-    form_class = WebLinkForm
-    post_action_redirect = reverse_lazy(
-        viewname='web_links:web_link_list'
-    )
-    view_permission = permission_web_link_create
-
-    def get_save_extra_data(self):
-        return {'_user': self.request.user}
-
-
-class WebLinkDeleteView(SingleObjectDeleteView):
-    model = WebLink
-    object_permission = permission_web_link_delete
-    pk_url_kwarg = 'web_link_id'
-    post_action_redirect = reverse_lazy(
-        viewname='web_links:web_link_list'
-    )
-
-    def get_extra_context(self):
-        return {
-            'object': self.object,
-            'title': _('Delete web link: %s') % self.object
-        }
-
-
-class WebLinkEditView(SingleObjectEditView):
-    form_class = WebLinkForm
-    model = WebLink
-    object_permission = permission_web_link_edit
-    pk_url_kwarg = 'web_link_id'
-    post_action_redirect = reverse_lazy(
-        viewname='web_links:web_link_list'
-    )
-
-    def get_extra_context(self):
-        return {
-            'object': self.object,
-            'title': _('Edit web link: %s') % self.object
-        }
-
-    def get_save_extra_data(self):
-        return {'_user': self.request.user}
