@@ -4,8 +4,6 @@ CELERY_BROKER_URL = 'memory://'
 CELERY_TASK_ALWAYS_EAGER = True
 CELERY_TASK_EAGER_PROPAGATES = True
 
-COMMON_PRODUCTION_ERROR_LOG_PATH = '/tmp/mayan-errors.log'
-
 DOCUMENT_PARSING_AUTO_PARSING = False
 
 FILE_METADATA_AUTO_PROCESS = False
@@ -14,13 +12,12 @@ INSTALLED_APPS = [
     cls for cls in INSTALLED_APPS if cls != 'whitenoise.runserver_nostatic'
 ]
 
-# Remove whitenoise from middlewares. Causes out of memory errors during test
-# suit
-MIDDLEWARE = [
-    cls for cls in MIDDLEWARE if cls != 'whitenoise.middleware.WhiteNoiseMiddleware'  # NOQA: F405
-]
+LOGGING_LOG_FILE_PATH = '/tmp/mayan-errors.log'
+LOGGING_LEVEL = 'WARNING'
 
 # Remove middlewares not used for tests
+# Remove whitenoise from middlewares. Causes out of memory errors during test
+# suit.
 MIDDLEWARE = [
     cls for cls in MIDDLEWARE if cls not in [
         'common.middleware.error_logging.ErrorLoggingMiddleware',
@@ -31,6 +28,7 @@ MIDDLEWARE = [
         'django.middleware.locale.LocaleMiddleware',
         'common.middleware.timezone.TimezoneMiddleware',
         'common.middleware.ajax_redirect.AjaxRedirect',
+        'whitenoise.middleware.WhiteNoiseMiddleware'
     ]
 ]
 
